<?php

namespace App\Http\Controllers;

use App\AdminItemGroup;
use App\AdminTermsAndCondition;
use App\Branches;
use App\S_A_terms_condition;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Http\Request;

class AdminTermsAndConditionController extends Controller
{
    use SoftDeletes;

    public function superadminIndex()
    {
        $terms = S_A_terms_condition::findOrFail(1);
        return view('super_admin.superadmin-terms-condition', compact('terms'));
    }

    function superadminTerms(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'description' => 'required|string',
            ]);

            S_A_terms_condition::findOrFail(1)->update(
                ['terms_conditions' => $validatedData['description']]
            );            
    
            flash()->addSuccess('Success');
            // return redirect()->route('crusher.terms_and_conditions.index');
            return back();
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function index()
    {
        $itemGroups = AdminItemGroup::where('branch_id', session()->get('selected_branch'))->get();
        return view('crusher..master_term&condition.delivery_not.index', compact('itemGroups'));
    }

    public function create()
    {
        $termsAndCondition = AdminTermsAndCondition::where(['branch_id'=>session()->get('selected_branch'), 'type'=>request()->type])->first();
        return view('crusher.master_term&condition.delivery_not.create', compact('termsAndCondition'));
    }

    function store(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'type' => 'required',
                'description' => 'required|string',
            ]);

            AdminTermsAndCondition::updateOrCreate(
                ['branch_id' => session()->get('selected_branch'), 'type' => $validatedData['type']],
                ['type' => $validatedData['type'], 'description' => $validatedData['description']]
            );            
    
            flash()->addSuccess('Success');
            // return redirect()->route('crusher.terms_and_conditions.index');
            return back();
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($itemGroup)
    {
        $itemGroup = AdminItemGroup::find($itemGroup);
        return view('crusher.itemgroup_master.edit', compact('itemGroup'));
    }

    function update(Request $request, $itemGroup)
    {
        try {
            $validatedData = $request->validate([
                'name' => 'required|string',
            ]);
    
            AdminItemGroup::find($itemGroup)->update($validatedData);
    
            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.terms_and_conditions.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($itemGroup)
    {
        $itemGroup = AdminItemGroup::find($itemGroup);
        return view('crusher.itemgroup_master.view', compact('itemGroup'));
    }

    public function softDelete($itemGroup)
    {
        $itemGroup = AdminItemGroup::findOrFail($itemGroup);
        $itemGroup->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.terms_and_conditions.index');
    }

    // TRANSFER
    function createTransfer()
    {
        $itemGroups = AdminItemGroup::where('branch_id', session()->get('selected_branch'))->get();
        $branches = Branches::whereHas('company', function($q){$q->where('user_id', auth()->id());})->where('id','!=',session()->get('selected_branch'))->get();
        return view('crusher.itemgroup_master.transfer_create', compact('itemGroups', 'branches'));
    }

    function transfer(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'branch' => 'required',
                'groups' => 'required|array',
                'groups.*' => 'required|exists:admin_item_groups,id',
            ]);

            foreach ($validatedData['groups'] as $key => $group) {
                AdminItemGroup::find($group)->update(['branch_id'=>$validatedData['branch']]);
            }
            
    
            flash()->addSuccess('Success');
            return redirect()->route('crusher.terms_and_conditions.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }
}
