<?php

namespace App\Http\Controllers;

use App\AdminOtherAccount;
use App\AdminSalesInvoice;
use App\AdminWarehouse;
use App\Branches;
use App\Company;
use App\CreditNote;
use App\CreditNoteExpense;
use App\Customer;
use App\Expense;
use App\ItemName;
use App\Quotation;
use App\StaffAndSalesman;
use App\Supplier;
use App\WareHouse;
use App\OtherAccountBuyer;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Permission;

class CreditNoteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $creditNotes = CreditNote::with('expenses')
            ->whereIn('id', function ($query) {
                $query->selectRaw('MIN(id)')
                    ->from('credit_notes')
                    ->where('branch_id', session()->get('selected_branch'))
                    ->whereNotNull('invoice_no')
                    ->groupBy('invoice_no');
            })
            ->withTrashed()
            ->orderBy('invoice_no', 'desc')->get();




        return view('crusher.trans_credit_note_srv.index', compact('creditNotes'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

         // Retrieve permission titles from Permission table
         $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

         // Filter permission titles using hasBranchPermission function
         $filteredPermissionTitles = [];
         $branchId = session()->get('selected_branch');
         foreach ($permissionTitles as $permissionTitle) {
             if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                 $filteredPermissionTitles[] = $permissionTitle;
             }
         }

        $customers = Customer::where('branch_id', session()->get('selected_branch'))->get();
        $items = ItemName::where('branch_id', session()->get('selected_branch'))->get();
        $warehouses = AdminWareHouse::where('branch_id', session()->get('selected_branch'))->get();
        $expenses = Expense::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });
        $otherAccountExpenses = AdminOtherAccount::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expensesAccount = $expenses->concat($otherAccountExpenses);

        $latestCn = CreditNote::withTrashed()->where('branch_id', session()->get('selected_branch'))
        ->latest('invoice_no')->first();

        if ($latestCn) {
            $lastNumber = (int)substr($latestCn->invoice_no, -4); // Extract the last 4 digits
            $newNumber = $lastNumber + 1;
            $newCn = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newCn = '0001';
        }

        // $newCn now contains the desired four-digit number without any prefix


        $salesInvoiceNo = request()->input('si');

        if ($salesInvoiceNo) {
            $salesInvoice = AdminSalesInvoice::with('account', 'item', 'warehouse', 'expenses')->where('invoice_no', $salesInvoiceNo)->get();
        } else {
            $salesInvoice = [];
        }

        $adminSales = AdminSalesInvoice::with('account', 'item')
            ->whereIn('id', function ($query) {
                $query->selectRaw('MIN(id)')
                    ->where('branch_id', session()->get('selected_branch'))
                    ->from('admin_sales_invoices')
                    ->groupBy('invoice_no');
            })->where('branch_id', session()->get('selected_branch'))
            ->get();

        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        // Concatenate all collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        // dd(session()->get('branch')->currency_decimal);

        return view('crusher.trans_credit_note_srv.create', compact('customers', 'items', 'newCn', 'warehouses', 'expensesAccount', 'adminSales', 'salesInvoice', 'accounts','expenses'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request);
        $latestNo = CreditNote::withTrashed()->where('branch_id', session()->get('selected_branch'))
        ->latest('invoice_no')->first();

        if ($latestNo) {
        $latestInvoiceNo = $latestNo->invoice_no;

        $latestNumber = (int)preg_replace('/[^0-9]/', '', $latestInvoiceNo);

        $newNumber = $latestNumber + 1;

        $newInvoiceNo = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
        $newInvoiceNo = '0001';
        }
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                // 'invoice_no' => 'nullable|string',
                'sales_invoice_no' => 'nullable|exists:admin_sales_invoices,invoice_no',
                'acc_no' => 'nullable',
                'account_id' => 'nullable',
                'account_type' => 'nullable',
                'account_name' => 'nullable',
                'item_description' => 'nullable|array',
                'item_description.*' => 'nullable|string',
                'quantity' => 'nullable|array',
                'quantity.*' => 'nullable|numeric',
                'rate_unit' => 'nullable|array',
                'rate_unit.*' => 'nullable|numeric',
                'gross_amount' => 'nullable|array',
                'gross_amount.*' => 'nullable|numeric',
                'vat_percentage' => 'nullable|array',
                'vat_percentage.*' => 'nullable|numeric',
                'vat_amount' => 'nullable|array',
                'vat_amount.*' => 'nullable|numeric',
                'net_amount' => 'nullable|array',
                'net_amount.*' => 'nullable|numeric',
                'total_quantity' => 'nullable|numeric',
                'total_gross_amount' => 'nullable|numeric',
                'total_vat_amount' => 'nullable|numeric',
                'total_net_amount' => 'nullable|numeric',
                'item_id' => 'nullable|array',
                'item_id.*' => 'nullable|exists:item_names,id',
                'warehouse_id' => 'nullable|array',
                'warehouse_id.*' => 'nullable|exists:admin_warehouses,id',
                'narrations' => 'nullable',
            ]);
            $branch_id = session()->get('selected_branch');



            // Iterate over the item descriptions
            for ($i = 0; $i < count($validatedData['quantity']); $i++) {
                $creditNoteData = [
                    'invoice_no' => $newInvoiceNo,
                    'sales_invoice_no' => $validatedData['sales_invoice_no'],
                    'date' => $validatedData['date'],
                    'account_id' => $validatedData['account_id'],
                    'acc_no' => $validatedData['acc_no'],
                    'account_type' => $validatedData['account_type'],
                    'account_name' => $validatedData['account_name'],
                    'item_description' => $validatedData['item_description'][$i] ?? (NULL),
                    'quantity' => $validatedData['quantity'][$i] ?? (NULL),
                    'rate_unit' => $validatedData['rate_unit'][$i] ?? (NULL),
                    'gross_amount' => $validatedData['gross_amount'][$i] ?? (NULL),
                    'vat_percentage' => $validatedData['vat_percentage'][$i] ?? (NULL),
                    'vat_amount' => $validatedData['vat_amount'][$i] ?? (NULL),
                    'net_amount' => $validatedData['net_amount'][$i] ?? (NULL),
                    'total_quantity' => $validatedData['total_quantity'],
                    'total_gross_amount' => $validatedData['total_gross_amount'],
                    'total_vat_amount' => $validatedData['total_vat_amount'],
                    'total_net_amount' => $validatedData['total_net_amount'],
                    'item_id' => $validatedData['item_id'][$i] ?? (NULL),
                    'warehouse_id' => $validatedData['warehouse_id'][$i] ?? (NULL),
                    'narrations' => $validatedData['narrations'],
                    'branch_id' => $branch_id,
                ];
                $creditNote = CreditNote::create($creditNoteData);


            }

            flash()->addSuccess('Record Created');
            return redirect()->route('software.credit_notes.index');
        } catch (\Throwable $th) {
            // dd($th);
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($creditNote)
    {
        $creditNote = CreditNote::withTrashed()->find($creditNote);
        $creditNote = $creditNote->with('account', 'item', 'warehouse', 'expenses.expense')
            ->where('invoice_no', $creditNote->invoice_no)
            ->withTrashed() // Include soft-deleted records
            ->where('branch_id', session()->get('selected_branch'))
            ->get();

        $company = Company::where('user_id', auth()->id())->first();

        return view('crusher.trans_credit_note_srv.view', compact('creditNote', 'company'));
    }

    public function edit(CreditNote $creditNote)
    {
         // Retrieve permission titles from Permission table
         $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

         // Filter permission titles using hasBranchPermission function
         $filteredPermissionTitles = [];
         $branchId = session()->get('selected_branch');
         foreach ($permissionTitles as $permissionTitle) {
             if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                 $filteredPermissionTitles[] = $permissionTitle;
             }
         }

        $customers = Customer::where('branch_id', session()->get('selected_branch'))->get();
        $items = ItemName::where('branch_id', session()->get('selected_branch'))->get();
        $warehouses = AdminWarehouse::where('branch_id', session()->get('selected_branch'))->get();
        $expenses = Expense::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });
        $otherAccountExpenses = AdminOtherAccount::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expensesAccount = $expenses->concat($otherAccountExpenses);

        $adminSales = AdminSalesInvoice::with('account', 'item')
        ->whereIn('id', function ($query) {
            $query->selectRaw('MIN(id)')
                ->from('admin_sales_invoices')
                ->groupBy('invoice_no');
        })->where('branch_id', session()->get('selected_branch'))
        ->get();

        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        // Concatenate all collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);


        // $creditNotes = $creditNote->with('account', 'item', 'warehouse', 'expenses')->where('invoice_no', $creditNote->invoice_no)->get();

        $creditNotes = CreditNote::where('branch_id', session()->get('selected_branch'))
        ->with(['account', 'item', 'warehouse', 'expenses'])
        ->where('invoice_no', $creditNote->invoice_no)
        ->get();

        // dd($creditNotes);

        return view('crusher.trans_credit_note_srv.edit', compact('items', 'warehouses', 'expensesAccount', 'accounts', 'creditNotes', 'adminSales'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Quotation  $quotation
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, CreditNote $creditNote)
    {

        // dd(request()->all());
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                'invoice_no' => 'nullable|string',
                'sales_invoice_no' => 'nullable|exists:admin_sales_invoices,invoice_no',
                'acc_no' => 'nullable',
                'account_id' => 'nullable',
                'account_type' => 'nullable',
                'account_name' => 'nullable',
                'item_description' => 'nullable|array',
                'item_description.*' => 'nullable|string',
                'quantity' => 'nullable|array',
                'quantity.*' => 'nullable|numeric',
                'rate_unit' => 'nullable|array',
                'rate_unit.*' => 'nullable|numeric',
                'gross_amount' => 'nullable|array',
                'gross_amount.*' => 'nullable|numeric',
                'vat_percentage' => 'nullable|array',
                'vat_percentage.*' => 'nullable|numeric',
                'vat_amount' => 'nullable|array',
                'vat_amount.*' => 'nullable|numeric',
                'net_amount' => 'nullable|array',
                'net_amount.*' => 'nullable|numeric',
                'expense_type' => 'nullable|array',
                'expense_type.*' => 'nullable',
                'expense_id' => 'nullable|array',
                'expense_id.*' => 'nullable',
                'expense_amount' => 'nullable|array',
                'expense_amount.*' => 'nullable|numeric',
                'total_quantity' => 'nullable|numeric',
                'total_gross_amount' => 'nullable|numeric',
                'total_vat_amount' => 'nullable|numeric',
                'total_net_amount' => 'nullable|numeric',
                'item_id' => 'nullable|array',
                'item_id.*' => 'nullable|exists:item_names,id',
                'warehouse_id' => 'nullable|array',
                'warehouse_id.*' => 'nullable|exists:admin_warehouses,id',
                'narrations' => 'nullable',
            ]);
            $branch_id = session()->get('selected_branch');
            $creditNotes = $creditNote->with('account', 'item', 'warehouse', 'expenses')->where('invoice_no', $creditNote->invoice_no)->forceDelete();

            // Iterate over the item descriptions
            for ($i = 0; $i < count($validatedData['quantity']); $i++) {
                $creditNoteData = [
                    'sales_invoice_no' => $validatedData['sales_invoice_no'],
                    'invoice_no' => $validatedData['invoice_no'],
                    'date' => $validatedData['date'],
                    'acc_no' => $validatedData['acc_no'],
                    'account_id' => $validatedData['account_id'],
                    'account_type' => $validatedData['account_type'],
                    'account_name' => $validatedData['account_name'],
                    'item_description' => $validatedData['item_description'][$i] ?? (NULL),
                    'quantity' => $validatedData['quantity'][$i] ?? (NULL),
                    'rate_unit' => $validatedData['rate_unit'][$i] ?? (NULL),
                    'gross_amount' => $validatedData['gross_amount'][$i] ?? (NULL),
                    'vat_percentage' => $validatedData['vat_percentage'][$i] ?? (NULL),
                    'vat_amount' => $validatedData['vat_amount'][$i] ?? (NULL),
                    'net_amount' => $validatedData['net_amount'][$i] ?? (NULL),
                    'total_quantity' => $validatedData['total_quantity'],
                    'total_gross_amount' => $validatedData['total_gross_amount'],
                    'total_vat_amount' => $validatedData['total_vat_amount'],
                    'total_net_amount' => $validatedData['total_net_amount'],
                    'item_id' => $validatedData['item_id'][$i] ?? (NULL),
                    'warehouse_id' => $validatedData['warehouse_id'][$i] ?? (NULL),
                    'narrations' => $validatedData['narrations'],
                    'branch_id' => $branch_id,
                ];

                $creditNote = CreditNote::create($creditNoteData);

                CreditNoteExpense::where('credit_note_id', $creditNote->id)->forceDelete();

                // Add expenses for this creditNote
                // for ($j = 0; $j < count($validatedData['expense_id']); $j++) {
                //     CreditNoteExpense::create([
                //         'credit_note_id' => $creditNote->id,
                //         'expense_type' => $validatedData['expense_type'][$j],
                //         'expense_id' => $validatedData['expense_id'][$j],
                //         'expense_amount' => $validatedData['expense_amount'][$j],
                //     ]);
                // }
            }

            flash()->addSuccess('Record Updated');
            return redirect()->route('software.credit_notes.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Quotation  $quotation
     * @return \Illuminate\Http\Response
     */
    public function destroy(Quotation $quotation)
    {
        //
    }

    public function softDelete()
    {
        $creditNotes = CreditNote::where('branch_id', session()->get('selected_branch'))->where('invoice_no', request()->invoice_no)->get();

        if ($creditNotes->isEmpty()) {
            flash()->addError('No records found for the given invoice number.');
            return redirect()->route('crusher.credit_notes.index');
        }

        foreach ($creditNotes as $creditNote) {
            $creditNote->delete();
        }

        flash()->addSuccess('Success');
        return redirect()->route('crusher.credit_notes.index');
    }
}
