<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Branches;
use App\AdminItemGroup;
use App\ItemName;
use App\AdminSalesInvoice;
use App\AdminPurchaesInvoice;
use App\Customer;
use App\DebitNote;
use App\CreditNote;
use App\OpeningBalance;
use App\Services\StockReportService;
class StockReportController extends Controller
{
    protected $stockReportService;

    public function __construct(StockReportService $stockReportService) {
        $this->stockReportService = $stockReportService;
    }

    public function completeStockWithQty(Request $request) {
        list($groupedItems, $groups, $from_date, $to_date,$allClosingStock,) = $this->stockReportService->completeStockReportClosingBalance($request, $request->from_date, $request->to_date);
        // dd($groupedItems, $groups, $from_date, $to_date,$allClosingStock);
        return view('crusher.reports.complete-stock-report-with-qty', compact('groupedItems', 'groups', 'from_date', 'to_date'));
    }

    public function completeStock(Request $request) {
        list($groupedItems, $groups, $from_date, $to_date,$allClosingStock,$allOpeningStock) = $this->stockReportService->completeStockReportClosingBalance($request, $request->from_date, $request->to_date);
        // dd($groupedItems, $groups, $from_date, $to_date,$allClosingStock);
        return view('crusher.reports.complete-stock-report', compact('groupedItems', 'groups', 'from_date', 'to_date'));
    }

    public function view()
    {
        $itemGroups = AdminItemGroup::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')->get();
        $itemNames = ItemName::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')->get();

        return view('crusher.reports.stock_report', compact('itemGroups','itemNames'));

    }
    public function allStockQuery(Request $request)
    {

        $selectedOption = $request->input('ledger_account_class_name');
        $showCost = $request->has('showCost');
        $showQty = $request->has('showQty');

        if ($selectedOption === 'group_query' && $showQty) {

            list($groupedItems, $groupName, $from_date, $to_date) = $this->stockReportService->groupStockReportClosingBalance($request, $request->from_date, $request->to_date);

            // dd($groupedItems, $groupName, $from_date, $to_date);

        return view('crusher.reports.group_stock_report_with_qty', compact('groupedItems','groupName','from_date', 'to_date'));
    }
        if ($selectedOption === 'group_query') {

            list($groupedItems, $groupName, $from_date, $to_date) = $this->stockReportService->groupStockReportClosingBalance($request, $request->from_date, $request->to_date);

            // dd($groupedItems, $groupName, $from_date, $to_date);

        return view('crusher.reports.stock_report_2', compact('groupedItems','groupName','from_date', 'to_date'));
    }

    elseif ($selectedOption === 'stock_query' && $showQty) {
        return redirect()->route('completeStockWithQty')->withInput();
    }
    elseif ($selectedOption === 'stock_query') {
        return redirect()->route('completeStock')->withInput();
    }

    elseif ($selectedOption === 'item_query' && $showCost) {
        return redirect()->route('show.cost')->withInput();
    }
    elseif ($selectedOption === 'item_query') {
        return redirect()->route('particular.item.query')->withInput();
    }

    }

    public function particularItemQueryWithShowCost(Request $request)

    {
        $from_date = $request->old('from_date');
        $to_date = $request->old('to_date');
        $item_stock = $request->old('item_stock');
        $currentYearFirstDate = date("2003-01-01");
        $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));
        $item = ItemName::find($item_stock);

        if (!$item) {
            abort(404);
        }


        $collectionOpeningBalanceForInventories = OpeningBalance::with([
                    'customer' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'supplier' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'StaffAndSalesman' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'Expense' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'AdminOtherAccount' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->orderBy('invoice_no')
                ->selectRaw('invoice_no,item_id,date,id,rate_unit, SUM(quantity) as quantity')
                ->get();
            // dd($collectionOpeningBalanceForInventories);

        $collectionSalesInvoices = AdminSalesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                // ->whereNotNull('invoice_no')
                ->groupBy('invoice_no')
                ->orderBy('invoice_no')
                ->selectRaw('invoice_no,date,id,rate_unit, SUM(quantity) as quantity')
                ->get();

        $collectionPurchaseInvoices = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->selectRaw('invoice_no,date,id,rate_unit, SUM(quantity) as quantity')
                ->get();
                // dd($collectionPurchaseInvoices);
        $collectionSalesReturns = CreditNote::with([
                    'customer' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'supplier' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'StaffAndSalesman' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'Expense' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    },
                    'AdminOtherAccount' => function ($query) {
                        $query->where('branch_id', session()->get('selected_branch'));
                    }
                    ])
                    ->where('branch_id', session()->get('selected_branch'))
                    ->where('item_id', $item_stock)
                    ->where('date', '>=', $from_date . ' 00:00:00')
                    ->where('date', '<=', $to_date . ' 23:59:59')
                    // ->whereNotNull('invoice_no')
                    ->whereNull('deleted_at')
                    ->groupBy('invoice_no')
                    // ->orderBy('invoice_no')
                    ->selectRaw('invoice_no,date,id,rate_unit, SUM(quantity) as quantity')
                    ->get();
        $collectionPurchaseReturns = debitNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            // ->whereNotNull('invoice_no')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            // ->orderBy('invoice_no')
            ->selectRaw('invoice_no,date,id,rate_unit, SUM(quantity) as quantity')
            ->get();
        $salesInvoices = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            // ->whereNotNull('invoice_no')
            ->groupBy('invoice_no')
            // ->orderBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit, SUM(quantity) as quantity')
            ->get();

        $purchaseInvoices = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->selectRaw('invoice_no,item_id,date,id,rate_unit,c_f, SUM(quantity) as quantity')
                ->get();
                // dd($purchaseInvoices);

        $openingBalanceForInventories = OpeningBalance::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit,c_f, SUM(quantity) as quantity')
            ->get();
            // dd($openingBalanceForInventories);

        $obSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit, SUM(quantity) as quantity')

            ->get();
        $obPurchaseInvoice = AdminPurchaesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit,c_f, SUM(quantity) as quantity')
            ->get();
        $obOpeningBalanceForInventories = OpeningBalance::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit,c_f, SUM(quantity) as quantity')
            ->get();

        $cbSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $from_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $cbPurchaseInvoice = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->orderBy('invoice_no')
                ->get();

        $salesReturns = CreditNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit, SUM(quantity) as quantity')
            ->get();
        $obSalesReturn = CreditNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->selectRaw('invoice_no,item_id,date,id,rate_unit, SUM(quantity) as quantity')
            ->get();
        $purchaseReturns = debitNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obPurchaseReturn = debitNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();

        // $mergedData
        // $openingBalanceForInventory = $openingBalanceForInventory->toArray();

        // $salesInvoice = $salesInvoice->toArray();
        // $originalPurchaseInvoice = $originalPurchaseInvoice->toArray();
        // $salesReturn = $salesReturn->toArray();
        // $purchaseReturn = $purchaseReturn->toArray();

        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseInvoice = $obPurchaseInvoice->toArray();
        // $obSalesReturn = $obSalesReturn->toArray();
        // $obPurchaseReturn = $obPurchaseReturn->toArray();

        // $workingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesInvoices = array_merge($obSalesReturn, $salesInvoice);
        // $workingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);
        // $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

        // $oborkingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice);
        // $oborkingSalesInvoices = array_merge($obSalesReturn);
        // $oborkingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice);
        // $oborkingSalesReturn = array_merge($obSalesReturn);
        // $oborkingPurchaseReturn = array_merge($obPurchaseReturn);


        $originalPurchaseInvoice = $purchaseInvoices->toArray();
        $openingBalanceForInventory = $openingBalanceForInventories->toArray();
        $salesInvoice = $salesInvoices->toArray();
        $purchaseReturn = $purchaseReturns->toArray();
        $salesReturn = $salesReturns->toArray();

        $obOpeningBalanceForInventory = $obOpeningBalanceForInventories->toArray();
        $obOriginalPurchaseInvoice = $obPurchaseInvoice->toArray();
        $obSalesInvoice = $obSalesInvoice->toArray();
        $obPurchaseReturn = $obPurchaseReturn->toArray();
        $obSalesReturn = $obSalesReturn->toArray();

        // Initialize variables
        $obWorkingSalesInvoices = $obSalesInvoice;

        // Copy original purchase invoices to work with
        $obWorkingOriginalPurchaseInvoice = array_merge($obOpeningBalanceForInventory,$obOriginalPurchaseInvoice);

        // Initialize arrays to store closing quantities and totals for each item_id
        $itemClosings = [];
        $obItemClosings = [];
        // Group original purchase invoices by item_id
        $obOriginalPurchaseInvoicesByItem = [];
        foreach ($obWorkingOriginalPurchaseInvoice as $purchase) {
            $item_id = $purchase['item_id'];
            if (!isset($obOriginalPurchaseInvoicesByItem[$item_id])) {
                $obOriginalPurchaseInvoicesByItem[$item_id] = [];
            }
            $obOriginalPurchaseInvoicesByItem[$item_id][] = $purchase;
        }

        // Group sales invoices by item_id
        $obSalesInvoicesByItem = [];
        foreach ($obSalesInvoice as $sale) {
            $item_id = $sale['item_id'];
            if (!isset($obSalesInvoicesByItem[$item_id])) {
                $obSalesInvoicesByItem[$item_id] = [];
            }
            $obSalesInvoicesByItem[$item_id][] = $sale;
        }

        // Iterate over each item_id
        foreach ($obOriginalPurchaseInvoicesByItem as $item_id => $purchases) {
            // Initialize closing total and quantity for the current item_id
            $obItemClosings[$item_id]['closingTotal'] = 0;
            $obItemClosings[$item_id]['closingQuantity'] = 0;

            // Calculate total cost and quantity from original purchases
            foreach ($purchases as $purchase) {
                $obItemClosings[$item_id]['closingTotal'] += $purchase['quantity'] * ($purchase['rate_unit'] + $purchase['c_f']);
                $obItemClosings[$item_id]['closingQuantity'] += $purchase['quantity'];
            }

            // Adjust for sales invoices
            if (isset($obSalesInvoicesByItem[$item_id])) {
                foreach ($obSalesInvoicesByItem[$item_id] as $sale) {
                    $saleQuantity = $sale['quantity'];

                    // Find corresponding original purchase invoices for this sale
                    foreach ($purchases as &$purchase) {
                        $soldQuantity = min($saleQuantity, $purchase['quantity']);
                        $saleQuantity -= $soldQuantity;
                        $purchase['quantity'] -= $soldQuantity;

                        // Update closing total and quantity
                        $obItemClosings[$item_id]['closingTotal'] -= $soldQuantity * ($purchase['rate_unit'] + $purchase['c_f']);
                        $obItemClosings[$item_id]['closingQuantity'] -= $soldQuantity;

                        if ($saleQuantity <= 0) {
                            break;
                        }
                    }
                }
            }
        }
        $obWorkingOriginalPurchaseInvoiceForReturns = array_merge($obOpeningBalanceForInventory,$originalPurchaseInvoice);
        $obWorkingSalesReturn = array_merge($obSalesReturn, $salesReturn);

        foreach ($obWorkingSalesReturn as $return) {
            $returnedQuantity = $return['quantity'];
            $itemId = $return['item_id'];

            foreach ($obWorkingOriginalPurchaseInvoiceForReturns as &$purchase) {
                if ($purchase['item_id'] === $itemId && isset($itemClosings[$itemId])) {
                    $purchaseQuantity = $purchase['quantity'];

                    $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

                    $itemClosings[$itemId]['closingTotal'] += $returnToPurchaseQuantity * ($purchase['rate_unit'] + $purchase['c_f']);

                    $itemClosings[$itemId]['closingQuantity'] += $returnToPurchaseQuantity;

                    $purchase['quantity'] -= $returnToPurchaseQuantity;

                    $returnedQuantity -= $returnToPurchaseQuantity;

                    if ($returnedQuantity <= 0) {

                    }
                }
            }
        }

        // foreach ($obSalesReturn as $return) {
        //     $returnedQuantity = $return['quantity'];
        //     $itemId = $return['item_id'];

        //     foreach ($obWorkingOriginalPurchaseInvoiceForReturns as &$purchase) {
        //         if ($purchase['item_id'] === $itemId) {
        //             $purchaseQuantity = $purchase['quantity'];

        //             $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

        //             $itemClosings[$itemId]['closingTotal'] += $returnToPurchaseQuantity * ($purchase['rate_unit'] + $purchase['c_f']);

        //             $itemClosings[$itemId]['closingQuantity'] += $returnToPurchaseQuantity;

        //             $purchase['quantity'] -= $returnToPurchaseQuantity;

        //             $returnedQuantity -= $returnToPurchaseQuantity;

        //             if ($returnedQuantity <= 0) {
        //             }
        //         }
        //     }
        // }

        // FIFO logic for debit notes (purchase returns)
        foreach ($obPurchaseReturn as $return) {
            $returnedQuantity = $return['quantity'];

            // Update closing total and quantity for each returned item
            $item_id = $return['item_id'];
            $obItemClosings[$item_id]['closingTotal'] -= $returnedQuantity * $return['rate_unit'];
            $obItemClosings[$item_id]['closingQuantity'] -= $returnedQuantity;
        }

        // // Output the closing quantities and totals for each item_id
        // dd($obItemClosings);

          // Initialize variables
        //   $workingSalesInvoices = $salesInvoice;

          // Copy original purchase invoices to work with
          // $workingOriginalPurchaseInvoice = $originalPurchaseInvoice;
          $workingOriginalPurchaseInvoice = array_merge($obOpeningBalanceForInventory,$openingBalanceForInventory, $obOriginalPurchaseInvoice, $originalPurchaseInvoice);

          // Initialize arrays to store closing quantities and totals for each item_id
          $itemClosings = [];
          // Group original purchase invoices by item_id
          $originalPurchaseInvoicesByItem = [];
          foreach ($workingOriginalPurchaseInvoice as $purchase) {
              $item_id = $purchase['item_id'];
              if (!isset($originalPurchaseInvoicesByItem[$item_id])) {
                  $originalPurchaseInvoicesByItem[$item_id] = [];
              }
              $originalPurchaseInvoicesByItem[$item_id][] = $purchase;
          }

          $workingSalesInvoice = array_merge($obSalesInvoice, $salesInvoice);

          // Group sales invoices by item_id
          $salesInvoicesByItem = [];
          foreach ($workingSalesInvoice as $sale) {
              $item_id = $sale['item_id'];
              if (!isset($salesInvoicesByItem[$item_id])) {
                  $salesInvoicesByItem[$item_id] = [];
              }
              $salesInvoicesByItem[$item_id][] = $sale;
          }

          // Iterate over each item_id
          foreach ($originalPurchaseInvoicesByItem as $item_id => $purchases) {
              // Initialize closing total and quantity for the current item_id
              $itemClosings[$item_id]['closingTotal'] = 0;
              $itemClosings[$item_id]['closingQuantity'] = 0;

              // Calculate total cost and quantity from original purchases
              foreach ($purchases as $purchase) {
                  $itemClosings[$item_id]['closingTotal'] += $purchase['quantity'] * ($purchase['rate_unit'] + $purchase['c_f']);
                  $itemClosings[$item_id]['closingQuantity'] += $purchase['quantity'];
              }
            //   dd($obItemClosings);

              // Adjust for sales invoices
              if (isset($salesInvoicesByItem[$item_id])) {
                  foreach ($salesInvoicesByItem[$item_id] as $sale) {
                      $saleQuantity = $sale['quantity'];

                      // Find corresponding original purchase invoices for this sale
                      foreach ($purchases as &$purchase) {
                          $soldQuantity = min($saleQuantity, $purchase['quantity']);
                          $saleQuantity -= $soldQuantity;
                          $purchase['quantity'] -= $soldQuantity;

                          // Update closing total and quantity
                          $itemClosings[$item_id]['closingTotal'] -= $soldQuantity * ($purchase['rate_unit'] + $purchase['c_f']);
                          $itemClosings[$item_id]['closingQuantity'] -= $soldQuantity;

                          if ($saleQuantity <= 0) {
                              break;
                          }
                      }
                  }
              }
          }

          // Copy original purchase invoices to work with for sales returns
          // $workingOriginalPurchaseInvoiceForReturns = $originalPurchaseInvoice;
          $workingOriginalPurchaseInvoiceForReturns = array_merge($obOpeningBalanceForInventory,$openingBalanceForInventory,$obOriginalPurchaseInvoice, $originalPurchaseInvoice);

          $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);

          foreach ($workingSalesReturn as $return) {
              $returnedQuantity = $return['quantity'];
              $itemId = $return['item_id'];

              // Iterate through copied original purchase invoices for returns
              foreach ($workingOriginalPurchaseInvoiceForReturns as &$purchase) {
                  // Check if the item_id matches the returned item_id
                  if ($purchase['item_id'] === $itemId) {
                      $purchaseQuantity = $purchase['quantity'];

                      // Calculate the quantity to be returned to the original purchase
                      $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

                      // Update closing total using the purchase rate
                      $itemClosings[$itemId]['closingTotal'] += $returnToPurchaseQuantity * ($purchase['rate_unit'] + $purchase['c_f']);

                      // Update closing quantity
                      $itemClosings[$itemId]['closingQuantity'] += $returnToPurchaseQuantity;

                      // Reduce the quantity of the copied original purchase
                      $purchase['quantity'] -= $returnToPurchaseQuantity;

                      $returnedQuantity -= $returnToPurchaseQuantity;

                      if ($returnedQuantity <= 0) {
                          break; // No need to continue if all returned quantities are processed
                      }
                  }
              }
          }
        //   dd($itemClosings);


          $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

          // FIFO logic for debit notes (purchase returns)
          foreach ($workingPurchaseReturn as $return) {
              $returnedQuantity = $return['quantity'];

              // Update closing total and quantity for each returned item
              $item_id = $return['item_id'];
              $itemClosings[$item_id]['closingTotal'] -= $returnedQuantity * $return['rate_unit'];
              $itemClosings[$item_id]['closingQuantity'] -= $returnedQuantity;
          }

          // // Output the closing quantities and totals for each item_id
        //   dd($itemClosings);

          $totalClosingQuantity = 0;
          $totalClosingTotal = 0;

          // Loop through the $itemClosings array to accumulate closing total and quantity
          foreach ($itemClosings as $item_id => $closing) {
              $totalClosingTotal += $closing['closingTotal'];
              $totalClosingQuantity += $closing['closingQuantity'];
          }

          // Output the total closing quantities and totals
        //   dd($totalClosingQuantity, $totalClosingTotal);



        // // Initialize variables
        // // $workingSalesInvoices = $salesInvoice;
        // $closingTotal = 0;

        // // Copy original purchase invoices to work with
        // // $workingOriginalPurchaseInvoice = $originalPurchaseInvoice;

        // $workingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesInvoices = array_merge($obSalesReturn, $salesInvoice);

        // // FIFO logic for purchases and sales
        // foreach ($workingOriginalPurchaseInvoice as $purchase) {
        //     $remainingQuantity = $purchase['quantity'];

        //     // Check if there are corresponding sales
        //     while ($remainingQuantity > 0 && !empty($workingSalesInvoices)) {
        //         $sale = array_shift($workingSalesInvoices);
        //         $soldQuantity = min($sale['quantity'], $remainingQuantity);

        //         // Calculate cost of goods sold
        //         $costOfGoodsSold = $soldQuantity * $purchase['rate_unit'];

        //         // Update closing total
        //         $closingTotal -= $costOfGoodsSold;
        //         $remainingQuantity -= $soldQuantity;
        //     }
        // }

        // $closingTotal = ($remainingQuantity * $purchase['rate_unit']);
        // // dd($closingTotal, $closingQuantity);

        // // Copy original purchase invoices to work with for sales returns
        // // $workingOriginalPurchaseInvoiceForReturns = $originalPurchaseInvoice;
        // $workingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);

        // $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);


        // foreach ($workingSalesReturn as $return) {
        //     $returnedQuantity = $return['quantity'];

        //     // Iterate through copied original purchase invoices for returns
        //     foreach ($workingOriginalPurchaseInvoiceForReturns as &$purchase) {
        //         $purchaseQuantity = $purchase['quantity'];

        //         // Calculate the quantity to be returned to the original purchase
        //         $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

        //         // Update closing total using the purchase rate
        //         $closingTotal += $returnToPurchaseQuantity * $purchase['rate_unit'];

        //         // Reduce the quantity of the copied original purchase
        //         $purchase['quantity'] -= $returnToPurchaseQuantity;

        //         $returnedQuantity -= $returnToPurchaseQuantity;
        //     }

        // }

        // $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

        // // FIFO logic for debit notes (purchase returns)
        // foreach ($workingPurchaseReturn as $return) {
        //     $returnedQuantity = $return['quantity'];

        //     // Update closing total
        //     $closingTotal -= $returnedQuantity * $return['rate_unit'];

        // }
        // dd($closingTotal, $closingQuantity);

        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseInvoice = $obPurchaseInvoice->toArray();

        $cbSalesInvoice = $cbSalesInvoice->toArray();
        $cbPurchaseInvoice = $cbPurchaseInvoice->toArray();

        $profits = [];
        $remainingPurchaseQty = [];
        $remainingPurchaseRate = [];
        $obRemainingPurchaseQty = [];
        $obRemainingPurchaseRate = [];
        $cbRemainingPurchaseQty = [];
        $cbRemainingPurchaseRate = [];

        $cbPurchaseInvoices = $cbPurchaseInvoice;

        foreach ($cbSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($cbPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - ($purchase['rate_unit'] + $purchase['c_f']));

                    $cbPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }
        $obPurchaseInvoices = $obOpeningBalanceForInventories ->concat($obPurchaseInvoice)->concat($obSalesReturn)->concat($obPurchaseReturn);

        foreach ($obSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($obPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - ($purchase['rate_unit'] + $purchase['c_f']));

                    $obPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }

        // $purchaseInvoice = array_merge($openingBalanceForInventory, $originalPurchaseInvoice,);
        // $PI = array_merge($openingBalanceForInventory, $originalPurchaseInvoice);

        // $originalPurchaseInvoice = $purchaseInvoices->toArray();
        // $salesInvoice = $salesInvoices->toArray();
        // $purchaseReturn = $purchaseReturns->toArray();
        // $salesReturn = $salesReturns->toArray();

        // $obOriginalPurchaseInvoice = $obPurchaseInvoice->toArray();
        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseReturn = $obPurchaseReturn->toArray();
        // $obSalesReturn = $obSalesReturn->toArray();

        // $PI = array_merge($obOriginalPurchaseInvoice, $originalPurchaseInvoice);
        // $SI = array_merge($obSalesInvoice, $salesInvoice);
        // $SR = array_merge($obSalesReturn, $salesReturn);
        // $PR = array_merge($obPurchaseReturn, $purchaseReturn);

        // $ObPiPi = $obPurchaseInvoices -> concat($purchaseInvoices);


        // $purchaseInvoice = collect($purchaseInvoice);
        // $purchaseInvoice = $purchaseInvoice->concat($purchaseReturn);
        // $piQty = 0;
        // $purchaseInvoice = $purchaseInvoice->map(function($i)use($piQty)
        // {
        //     if(!isset($i['sales_invoice_no']))
        //     {
        //         $piQty += $i['quantity'];
        //         $i['remaning_quantity'] = $piQty;
        //     }
        //     return $i;
        // });

        // $purchaseInvoice = collect($purchaseInvoice);
        // $purchaseInvoice = $purchaseInvoice->concat($purchaseReturn);
        // $piQty = 0;
        // $purchaseInvoice = $purchaseInvoice->map(function($i) use (&$piQty) {
        //     if(!isset($i['invoice_no'])) {
        //         $piQty += $i['quantity'];
        //         $i['remaining_quantity'] = $piQty;
        //     } else {
        //         $i['remaining_quantity'] = $i['quantity'];
        //     }
        //     return $i;
        // });

        // $purchaseReturn = collect($purchaseReturn);

        // $purchaseReturnQty = $purchaseReturn->sum('quantity');
        // $totalPurchaseQty = $purchaseInvoice->whereNotIn('invoice_no', null)->sum('quantity');
        // $remainingPurchaseQty = $totalPurchaseQty - $purchaseReturnQty;

        // $purchaseInvoiceRateUnitTotal = $purchaseInvoice->whereNotIn('invoice_no', null)->sum(function($item) {
        //     return $item['rate_unit'] * $item['quantity'];
        // });

        // $purchaseReturnRateUnitTotal = $purchaseReturn->sum(function($item) {
        //     return $item['rate_unit'] * $item['quantity'];
        // });

        // $remainingRateUnit = $purchaseInvoiceRateUnitTotal - $purchaseReturnRateUnitTotal;

        // dd($remainingPurchaseQty, $remainingRateUnit);

        // // dd($remainingPurchaseQty);

        // $salesInvoice = collect($salesInvoice);
        // $siQty = 0;
        // $salesInvoice = $salesInvoice->map(function($i) use (&$siQty) {
        //     if(!isset($i['invoice_no'])) {
        //         $siQty += $i['quantity'];
        //         $i['remaining_quantity'] = $siQty;
        //     } else {
        //         $i['remaining_quantity'] = $i['quantity'];
        //     }
        //     return $i;
        // });

        // $salesReturn = collect($salesReturn);

        // $salesReturnQty = $salesReturn->sum('quantity');
        // $totalSalesQty = $salesInvoice->whereNotIn('invoice_no', null)->sum('quantity');
        // $remainingSalesQty = $totalSalesQty - $salesReturnQty;

        // dd($remainingPurchaseQty,$remainingSalesQty);

        $PI = array_merge($obOpeningBalanceForInventory,$openingBalanceForInventory, $obPurchaseInvoices->toArray(), $originalPurchaseInvoice);
        $PPI = array_merge($obOpeningBalanceForInventory,$openingBalanceForInventory, $obPurchaseInvoices->toArray(), $originalPurchaseInvoice);

        foreach ($salesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($PPI as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - ($purchase['rate_unit'] + $purchase['c_f']));

                    $PPI[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;
        }

        foreach ($salesReturn as $key => &$return) {
            $qtyToReturn = $return['quantity'];
            $rate = $return['rate_unit'];
            $profit = 0;

            foreach ($PI as $saleKey => &$sale) {
                $saleQty = $sale['quantity'];

                if ($qtyToReturn > 0 && $saleQty > 0) {
                    $unitsReturned = min($qtyToReturn, $saleQty);

                    $profit += ($rate - $sale['rate_unit']) * $unitsReturned;

                    $PI[$saleKey]['quantity'] -= $unitsReturned;

                    $qtyToReturn -= $unitsReturned;
                }
            }

            unset($sale);

            $profits[$return['id']] = $profit;
            $return['profit'] = $profit;
        }

        foreach ($purchaseReturn as $key => &$return) {
            $qtyToReturn = $return['quantity'];
            $rate = $return['rate_unit'];
            $profit = 0;

            foreach ($PPI as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToReturn > 0 && $purchaseQty > 0) {
                    $unitsReturned = min($qtyToReturn, $purchaseQty);

                    // $profit += $unitsReturned * ($rate - $purchase['rate_unit']);

                    $PPI[$purchaseKey]['quantity'] -= $unitsReturned;

                    $qtyToReturn -= $unitsReturned;
                }
            }

            unset($purchase);

            // $profits[$return['id']] = $profit;
            // $return['profit'] = $profit;
        }

        // foreach ([$salesInvoice, $salesReturn, $purchaseReturn] as $transactions) {
        //     foreach ($transactions as $key => &$transaction) {
        //         $qtyToProcess = $transaction['quantity'];
        //         $rate = $transaction['rate_unit'];
        //         $profit = 0;

        //         foreach ($purchaseInvoice as $purchaseKey => &$purchase) {
        //             $purchaseQty = $purchase['quantity'];

        //             if ($qtyToProcess > 0 && $purchaseQty > 0) {
        //                 $unitsProcessed = min($qtyToProcess, $purchaseQty);

        //                 if ($transaction === $purchase) {
        //                     // For sales transactions
        //                     $profit += $unitsProcessed * ($rate - $purchase['rate_unit']);
        //                 } else {
        //                     // For return transactions
        //                     $profit -= $unitsProcessed * ($rate - $purchase['rate_unit']);
        //                 }

        //                 $purchaseInvoice[$purchaseKey]['quantity'] -= $unitsProcessed;

        //                 $qtyToProcess -= $unitsProcessed;
        //             }
        //         }

        //         unset($purchase);

        //         $profits[$transaction['id']] = $profit;
        //         $transaction['profit'] = $profit;
        //     }
        // }


        // dd($salesInvoice,$salesReturn,$purchaseReturn);

        foreach ($purchaseInvoices as $purchaseKey => $remainingPurchase) {
            $remainingPurchaseQty[$purchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $remainingPurchaseRate[$purchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];

        }
        // dd($remainingPurchaseQty);
        foreach ($obPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $obRemainingPurchaseQty[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $obRemainingPurchaseRate[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        foreach ($cbPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $cbRemainingPurchaseQty[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $cbRemainingPurchaseRate[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        $totalRemainingPurchaseQty = array_sum($remainingPurchaseQty);
        $totalRemainingPurchaseRate = array_sum($remainingPurchaseRate);
        $totalObRemainingPurchaseQty = array_sum($obRemainingPurchaseQty);
        $totalObRemainingPurchaseRate = array_sum($obRemainingPurchaseRate);
        $totalcbRemainingPurchaseQty = array_sum($cbRemainingPurchaseQty);
        $totalcbRemainingPurchaseRate = array_sum($cbRemainingPurchaseRate);

        // $concatenatedData = array_merge($openingBalanceForInventory, $originalPurchaseInvoice, $salesInvoice);

        $originalOpeningBalanceForInventories = collect($collectionOpeningBalanceForInventories);
        $originalPurchaseInvoice = collect($collectionPurchaseInvoices);
        $originalSalesInvoice = collect($collectionSalesInvoices);
        $originalSalesReturn = collect($collectionSalesReturns);
        $originalPurchaseReturn = collect($collectionPurchaseReturns);

        $allData = $originalOpeningBalanceForInventories
        ->concat($originalPurchaseInvoice)
        ->concat($originalSalesInvoice)
        ->concat($originalSalesReturn)
        ->concat($originalPurchaseReturn);

            // dd($allData);

        // dd($openingBalanceForInventory,$originalPurchaseInvoice,$salesInvoice);

        return view('crusher.reports.particular-item-query-show-cost', compact('item', 'salesInvoice','openingBalanceForInventory','originalPurchaseInvoice', 'from_date', 'to_date', 'item_stock','profits','totalRemainingPurchaseQty','totalRemainingPurchaseRate','totalObRemainingPurchaseQty','totalObRemainingPurchaseRate','totalcbRemainingPurchaseQty','totalcbRemainingPurchaseRate','salesReturn','purchaseReturn','totalClosingQuantity','totalClosingTotal','allData'));
    }
    public function particularItemQuery(Request $request)

    {
        $from_date = $request->old('from_date');
        $to_date = $request->old('to_date');
        $item_stock = $request->old('item_stock');
        $currentYearFirstDate = date("2003-01-01");
        $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));
        $item = ItemName::find($item_stock);

        if (!$item) {
            abort(404);
        }

        $salesInvoices = AdminSalesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                // ->whereNull('deleted_at')
                // ->whereNotNull('invoice_no')
                ->groupBy('invoice_no')
                // ->orderBy('invoice_no')
                ->get();


        $purchaseInvoices = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNotNull('invoice_no')
                ->orderBy('invoice_no')
                ->get();

        $openingBalanceForInventory = OpeningBalance::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNotNull('invoice_no')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obPurchaseInvoice = AdminPurchaesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNotNull('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $cbSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $from_date . ' 23:59:59')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $cbPurchaseInvoice = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
                ])
                ->where('branch_id', session()->get('selected_branch'))
                ->where('item_id', $item_stock)
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNotNull('invoice_no')
                ->orderBy('invoice_no')
                ->get();

        $salesReturns = CreditNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNotNull('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obSalesReturn = CreditNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNotNull('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $purchaseReturns = debitNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNotNull('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obPurchaseReturn = debitNote::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNotNull('invoice_no')
            ->orderBy('invoice_no')
            ->get();

        // $mergedData
        // $openingBalanceForInventory = $openingBalanceForInventory->toArray();

        // $salesInvoice = $salesInvoice->toArray();
        // $originalPurchaseInvoice = $originalPurchaseInvoice->toArray();
        // $salesReturn = $salesReturn->toArray();
        // $purchaseReturn = $purchaseReturn->toArray();

        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseInvoice = $obPurchaseInvoice->toArray();
        // $obSalesReturn = $obSalesReturn->toArray();
        // $obPurchaseReturn = $obPurchaseReturn->toArray();

        // $workingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesInvoices = array_merge($obSalesReturn, $salesInvoice);
        // $workingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);
        // $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

        // $oborkingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice);
        // $oborkingSalesInvoices = array_merge($obSalesReturn);
        // $oborkingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice);
        // $oborkingSalesReturn = array_merge($obSalesReturn);
        // $oborkingPurchaseReturn = array_merge($obPurchaseReturn);


        $originalPurchaseInvoice = $purchaseInvoices->toArray();
        $salesInvoice = $salesInvoices->toArray();
        $purchaseReturn = $purchaseReturns->toArray();
        $salesReturn = $salesReturns->toArray();

        $obOriginalPurchaseInvoice = $obPurchaseInvoice->toArray();
        $obSalesInvoice = $obSalesInvoice->toArray();
        $obPurchaseReturn = $obPurchaseReturn->toArray();
        $obSalesReturn = $obSalesReturn->toArray();

        // Initialize variables
        $obWorkingSalesInvoices = $obSalesInvoice;

        // Copy original purchase invoices to work with
        $obWorkingOriginalPurchaseInvoice = $obOriginalPurchaseInvoice;

        // Initialize arrays to store closing quantities and totals for each item_id
        $itemClosings = [];
        $obItemClosings = [];
        // Group original purchase invoices by item_id
        $obOriginalPurchaseInvoicesByItem = [];
        foreach ($obOriginalPurchaseInvoice as $purchase) {
            $item_id = $purchase['item_id'];
            if (!isset($obOriginalPurchaseInvoicesByItem[$item_id])) {
                $obOriginalPurchaseInvoicesByItem[$item_id] = [];
            }
            $obOriginalPurchaseInvoicesByItem[$item_id][] = $purchase;
        }

        // Group sales invoices by item_id
        $obSalesInvoicesByItem = [];
        foreach ($obSalesInvoice as $sale) {
            $item_id = $sale['item_id'];
            if (!isset($obSalesInvoicesByItem[$item_id])) {
                $obSalesInvoicesByItem[$item_id] = [];
            }
            $obSalesInvoicesByItem[$item_id][] = $sale;
        }

        // Iterate over each item_id
        foreach ($obOriginalPurchaseInvoicesByItem as $item_id => $purchases) {
            // Initialize closing total and quantity for the current item_id
            $obItemClosings[$item_id]['closingTotal'] = 0;
            $obItemClosings[$item_id]['closingQuantity'] = 0;

            // Calculate total cost and quantity from original purchases
            foreach ($purchases as $purchase) {
                $obItemClosings[$item_id]['closingTotal'] += $purchase['quantity'] * $purchase['rate_unit'];
                $obItemClosings[$item_id]['closingQuantity'] += $purchase['quantity'];
            }

            // Adjust for sales invoices
            if (isset($obSalesInvoicesByItem[$item_id])) {
                foreach ($obSalesInvoicesByItem[$item_id] as $sale) {
                    $saleQuantity = $sale['quantity'];

                    // Find corresponding original purchase invoices for this sale
                    foreach ($purchases as &$purchase) {
                        $soldQuantity = min($saleQuantity, $purchase['quantity']);
                        $saleQuantity -= $soldQuantity;
                        $purchase['quantity'] -= $soldQuantity;

                        // Update closing total and quantity
                        $obItemClosings[$item_id]['closingTotal'] -= $soldQuantity * $purchase['rate_unit'];
                        $obItemClosings[$item_id]['closingQuantity'] -= $soldQuantity;

                        if ($saleQuantity <= 0) {
                            break;
                        }
                    }
                }
            }
        }
        // Copy original purchase invoices to work with for sales returns
        $obWorkingOriginalPurchaseInvoiceForReturns = $originalPurchaseInvoice;

        foreach ($obSalesReturn as $return) {
            $returnedQuantity = $return['quantity'];
            $itemId = $return['item_id'];

            // Iterate through copied original purchase invoices for returns
            foreach ($obWorkingOriginalPurchaseInvoiceForReturns as &$purchase) {
                // Check if the item_id matches the returned item_id
                if ($purchase['item_id'] === $itemId) {
                    $purchaseQuantity = $purchase['quantity'];

                    // Calculate the quantity to be returned to the original purchase
                    $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

                    // Update closing total using the purchase rate
                    $itemClosings[$itemId]['closingTotal'] += $returnToPurchaseQuantity * $purchase['rate_unit'];

                    // Update closing quantity
                    $itemClosings[$itemId]['closingQuantity'] += $returnToPurchaseQuantity;

                    // Reduce the quantity of the copied original purchase
                    $purchase['quantity'] -= $returnToPurchaseQuantity;

                    $returnedQuantity -= $returnToPurchaseQuantity;

                    if ($returnedQuantity <= 0) {
                        break; // No need to continue if all returned quantities are processed
                    }
                }
            }
        }

        // FIFO logic for debit notes (purchase returns)
        foreach ($obPurchaseReturn as $return) {
            $returnedQuantity = $return['quantity'];

            // Update closing total and quantity for each returned item
            $item_id = $return['item_id'];
            $obItemClosings[$item_id]['closingTotal'] -= $returnedQuantity * $return['rate_unit'];
            $obItemClosings[$item_id]['closingQuantity'] -= $returnedQuantity;
        }

        // // Output the closing quantities and totals for each item_id
        // dd($obItemClosings);

          // Initialize variables
          $workingSalesInvoices = $salesInvoice;

          // Copy original purchase invoices to work with
          // $workingOriginalPurchaseInvoice = $originalPurchaseInvoice;
          $workingOriginalPurchaseInvoice = array_merge($obOriginalPurchaseInvoice, $originalPurchaseInvoice);

          // Initialize arrays to store closing quantities and totals for each item_id
          $itemClosings = [];
          // Group original purchase invoices by item_id
          $originalPurchaseInvoicesByItem = [];
          foreach ($workingOriginalPurchaseInvoice as $purchase) {
              $item_id = $purchase['item_id'];
              if (!isset($originalPurchaseInvoicesByItem[$item_id])) {
                  $originalPurchaseInvoicesByItem[$item_id] = [];
              }
              $originalPurchaseInvoicesByItem[$item_id][] = $purchase;
          }

          $workingSalesInvoice = array_merge($obSalesInvoice, $salesInvoice);

          // Group sales invoices by item_id
          $salesInvoicesByItem = [];
          foreach ($workingSalesInvoice as $sale) {
              $item_id = $sale['item_id'];
              if (!isset($salesInvoicesByItem[$item_id])) {
                  $salesInvoicesByItem[$item_id] = [];
              }
              $salesInvoicesByItem[$item_id][] = $sale;
          }

          // Iterate over each item_id
          foreach ($originalPurchaseInvoicesByItem as $item_id => $purchases) {
              // Initialize closing total and quantity for the current item_id
              $itemClosings[$item_id]['closingTotal'] = 0;
              $itemClosings[$item_id]['closingQuantity'] = 0;

              // Calculate total cost and quantity from original purchases
              foreach ($purchases as $purchase) {
                  $itemClosings[$item_id]['closingTotal'] += $purchase['quantity'] * $purchase['rate_unit'];
                  $itemClosings[$item_id]['closingQuantity'] += $purchase['quantity'];
              }

              // Adjust for sales invoices
              if (isset($salesInvoicesByItem[$item_id])) {
                  foreach ($salesInvoicesByItem[$item_id] as $sale) {
                      $saleQuantity = $sale['quantity'];

                      // Find corresponding original purchase invoices for this sale
                      foreach ($purchases as &$purchase) {
                          $soldQuantity = min($saleQuantity, $purchase['quantity']);
                          $saleQuantity -= $soldQuantity;
                          $purchase['quantity'] -= $soldQuantity;

                          // Update closing total and quantity
                          $itemClosings[$item_id]['closingTotal'] -= $soldQuantity * $purchase['rate_unit'];
                          $itemClosings[$item_id]['closingQuantity'] -= $soldQuantity;

                          if ($saleQuantity <= 0) {
                              break;
                          }
                      }
                  }
              }
          }
          // Copy original purchase invoices to work with for sales returns
          // $workingOriginalPurchaseInvoiceForReturns = $originalPurchaseInvoice;
          $workingOriginalPurchaseInvoiceForReturns = array_merge($obOriginalPurchaseInvoice, $originalPurchaseInvoice);

          $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);

          foreach ($workingSalesReturn as $return) {
              $returnedQuantity = $return['quantity'];
              $itemId = $return['item_id'];

              // Iterate through copied original purchase invoices for returns
              foreach ($workingOriginalPurchaseInvoiceForReturns as &$purchase) {
                  // Check if the item_id matches the returned item_id
                  if ($purchase['item_id'] === $itemId) {
                      $purchaseQuantity = $purchase['quantity'];

                      // Calculate the quantity to be returned to the original purchase
                      $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

                      // Update closing total using the purchase rate
                      $itemClosings[$itemId]['closingTotal'] += $returnToPurchaseQuantity * $purchase['rate_unit'];

                      // Update closing quantity
                      $itemClosings[$itemId]['closingQuantity'] += $returnToPurchaseQuantity;

                      // Reduce the quantity of the copied original purchase
                      $purchase['quantity'] -= $returnToPurchaseQuantity;

                      $returnedQuantity -= $returnToPurchaseQuantity;

                      if ($returnedQuantity <= 0) {
                          break; // No need to continue if all returned quantities are processed
                      }
                  }
              }
          }

          $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

          // FIFO logic for debit notes (purchase returns)
          foreach ($workingPurchaseReturn as $return) {
              $returnedQuantity = $return['quantity'];

              // Update closing total and quantity for each returned item
              $item_id = $return['item_id'];
              $itemClosings[$item_id]['closingTotal'] -= $returnedQuantity * $return['rate_unit'];
              $itemClosings[$item_id]['closingQuantity'] -= $returnedQuantity;
          }

          // // Output the closing quantities and totals for each item_id
        //   dd($itemClosings);

          $totalClosingQuantity = 0;
          $totalClosingTotal = 0;

          // Loop through the $itemClosings array to accumulate closing total and quantity
          foreach ($itemClosings as $item_id => $closing) {
              $totalClosingTotal += $closing['closingTotal'];
              $totalClosingQuantity += $closing['closingQuantity'];
          }

          // Output the total closing quantities and totals
        //   dd($totalClosingQuantity, $totalClosingTotal);



        // // Initialize variables
        // // $workingSalesInvoices = $salesInvoice;
        // $closingTotal = 0;

        // // Copy original purchase invoices to work with
        // // $workingOriginalPurchaseInvoice = $originalPurchaseInvoice;

        // $workingOriginalPurchaseInvoice = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);
        // $workingSalesInvoices = array_merge($obSalesReturn, $salesInvoice);

        // // FIFO logic for purchases and sales
        // foreach ($workingOriginalPurchaseInvoice as $purchase) {
        //     $remainingQuantity = $purchase['quantity'];

        //     // Check if there are corresponding sales
        //     while ($remainingQuantity > 0 && !empty($workingSalesInvoices)) {
        //         $sale = array_shift($workingSalesInvoices);
        //         $soldQuantity = min($sale['quantity'], $remainingQuantity);

        //         // Calculate cost of goods sold
        //         $costOfGoodsSold = $soldQuantity * $purchase['rate_unit'];

        //         // Update closing total
        //         $closingTotal -= $costOfGoodsSold;
        //         $remainingQuantity -= $soldQuantity;
        //     }
        // }

        // $closingTotal = ($remainingQuantity * $purchase['rate_unit']);
        // // dd($closingTotal, $closingQuantity);

        // // Copy original purchase invoices to work with for sales returns
        // // $workingOriginalPurchaseInvoiceForReturns = $originalPurchaseInvoice;
        // $workingOriginalPurchaseInvoiceForReturns = array_merge($obPurchaseInvoice, $originalPurchaseInvoice);

        // $workingSalesReturn = array_merge($obSalesReturn, $salesReturn);


        // foreach ($workingSalesReturn as $return) {
        //     $returnedQuantity = $return['quantity'];

        //     // Iterate through copied original purchase invoices for returns
        //     foreach ($workingOriginalPurchaseInvoiceForReturns as &$purchase) {
        //         $purchaseQuantity = $purchase['quantity'];

        //         // Calculate the quantity to be returned to the original purchase
        //         $returnToPurchaseQuantity = min($returnedQuantity, $purchaseQuantity);

        //         // Update closing total using the purchase rate
        //         $closingTotal += $returnToPurchaseQuantity * $purchase['rate_unit'];

        //         // Reduce the quantity of the copied original purchase
        //         $purchase['quantity'] -= $returnToPurchaseQuantity;

        //         $returnedQuantity -= $returnToPurchaseQuantity;
        //     }

        // }

        // $workingPurchaseReturn = array_merge($obPurchaseReturn, $purchaseReturn);

        // // FIFO logic for debit notes (purchase returns)
        // foreach ($workingPurchaseReturn as $return) {
        //     $returnedQuantity = $return['quantity'];

        //     // Update closing total
        //     $closingTotal -= $returnedQuantity * $return['rate_unit'];

        // }
        // dd($closingTotal, $closingQuantity);

        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseInvoice = $obPurchaseInvoice->toArray();

        $cbSalesInvoice = $cbSalesInvoice->toArray();
        $cbPurchaseInvoice = $cbPurchaseInvoice->toArray();

        $profits = [];
        $remainingPurchaseQty = [];
        $remainingPurchaseRate = [];
        $obRemainingPurchaseQty = [];
        $obRemainingPurchaseRate = [];
        $cbRemainingPurchaseQty = [];
        $cbRemainingPurchaseRate = [];

        $cbPurchaseInvoices = $cbPurchaseInvoice;

        foreach ($cbSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($cbPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $cbPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }
        $obPurchaseInvoices = $obPurchaseInvoice;

        foreach ($obSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($obPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $obPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }

        // $purchaseInvoice = array_merge($openingBalanceForInventory, $originalPurchaseInvoice,);
        // $PI = array_merge($openingBalanceForInventory, $originalPurchaseInvoice);

        // $originalPurchaseInvoice = $purchaseInvoices->toArray();
        // $salesInvoice = $salesInvoices->toArray();
        // $purchaseReturn = $purchaseReturns->toArray();
        // $salesReturn = $salesReturns->toArray();

        // $obOriginalPurchaseInvoice = $obPurchaseInvoice->toArray();
        // $obSalesInvoice = $obSalesInvoice->toArray();
        // $obPurchaseReturn = $obPurchaseReturn->toArray();
        // $obSalesReturn = $obSalesReturn->toArray();

        // $PI = array_merge($obOriginalPurchaseInvoice, $originalPurchaseInvoice);
        // $SI = array_merge($obSalesInvoice, $salesInvoice);
        // $SR = array_merge($obSalesReturn, $salesReturn);
        // $PR = array_merge($obPurchaseReturn, $purchaseReturn);

        // $ObPiPi = $obPurchaseInvoices -> concat($purchaseInvoices);


        // $purchaseInvoice = collect($purchaseInvoice);
        // $purchaseInvoice = $purchaseInvoice->concat($purchaseReturn);
        // $piQty = 0;
        // $purchaseInvoice = $purchaseInvoice->map(function($i)use($piQty)
        // {
        //     if(!isset($i['sales_invoice_no']))
        //     {
        //         $piQty += $i['quantity'];
        //         $i['remaning_quantity'] = $piQty;
        //     }
        //     return $i;
        // });

        // $purchaseInvoice = collect($purchaseInvoice);
        // $purchaseInvoice = $purchaseInvoice->concat($purchaseReturn);
        // $piQty = 0;
        // $purchaseInvoice = $purchaseInvoice->map(function($i) use (&$piQty) {
        //     if(!isset($i['invoice_no'])) {
        //         $piQty += $i['quantity'];
        //         $i['remaining_quantity'] = $piQty;
        //     } else {
        //         $i['remaining_quantity'] = $i['quantity'];
        //     }
        //     return $i;
        // });

        // $purchaseReturn = collect($purchaseReturn);

        // $purchaseReturnQty = $purchaseReturn->sum('quantity');
        // $totalPurchaseQty = $purchaseInvoice->whereNotIn('invoice_no', null)->sum('quantity');
        // $remainingPurchaseQty = $totalPurchaseQty - $purchaseReturnQty;

        // $purchaseInvoiceRateUnitTotal = $purchaseInvoice->whereNotIn('invoice_no', null)->sum(function($item) {
        //     return $item['rate_unit'] * $item['quantity'];
        // });

        // $purchaseReturnRateUnitTotal = $purchaseReturn->sum(function($item) {
        //     return $item['rate_unit'] * $item['quantity'];
        // });

        // $remainingRateUnit = $purchaseInvoiceRateUnitTotal - $purchaseReturnRateUnitTotal;

        // dd($remainingPurchaseQty, $remainingRateUnit);

        // // dd($remainingPurchaseQty);

        // $salesInvoice = collect($salesInvoice);
        // $siQty = 0;
        // $salesInvoice = $salesInvoice->map(function($i) use (&$siQty) {
        //     if(!isset($i['invoice_no'])) {
        //         $siQty += $i['quantity'];
        //         $i['remaining_quantity'] = $siQty;
        //     } else {
        //         $i['remaining_quantity'] = $i['quantity'];
        //     }
        //     return $i;
        // });

        // $salesReturn = collect($salesReturn);

        // $salesReturnQty = $salesReturn->sum('quantity');
        // $totalSalesQty = $salesInvoice->whereNotIn('invoice_no', null)->sum('quantity');
        // $remainingSalesQty = $totalSalesQty - $salesReturnQty;

        // dd($remainingPurchaseQty,$remainingSalesQty);

        $PI = array_merge($obPurchaseInvoices->toArray(), $originalPurchaseInvoice);
        $PPI = array_merge($obPurchaseInvoices->toArray(), $originalPurchaseInvoice);

        foreach ($salesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($PPI as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $PPI[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;
        }

        foreach ($salesReturn as $key => &$return) {
            $qtyToReturn = $return['quantity'];
            $rate = $return['rate_unit'];
            $profit = 0;

            foreach ($PI as $saleKey => &$sale) {
                $saleQty = $sale['quantity'];

                if ($qtyToReturn > 0 && $saleQty > 0) {
                    $unitsReturned = min($qtyToReturn, $saleQty);

                    $profit += ($rate - $sale['rate_unit']) * $unitsReturned;

                    $PI[$saleKey]['quantity'] -= $unitsReturned;

                    $qtyToReturn -= $unitsReturned;
                }
            }

            unset($sale);

            $profits[$return['id']] = $profit;
            $return['profit'] = $profit;
        }

        foreach ($purchaseReturn as $key => &$return) {
            $qtyToReturn = $return['quantity'];
            $rate = $return['rate_unit'];
            $profit = 0;

            foreach ($PPI as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToReturn > 0 && $purchaseQty > 0) {
                    $unitsReturned = min($qtyToReturn, $purchaseQty);

                    // $profit += $unitsReturned * ($rate - $purchase['rate_unit']);

                    $PPI[$purchaseKey]['quantity'] -= $unitsReturned;

                    $qtyToReturn -= $unitsReturned;
                }
            }

            unset($purchase);

            // $profits[$return['id']] = $profit;
            // $return['profit'] = $profit;
        }

        // foreach ([$salesInvoice, $salesReturn, $purchaseReturn] as $transactions) {
        //     foreach ($transactions as $key => &$transaction) {
        //         $qtyToProcess = $transaction['quantity'];
        //         $rate = $transaction['rate_unit'];
        //         $profit = 0;

        //         foreach ($purchaseInvoice as $purchaseKey => &$purchase) {
        //             $purchaseQty = $purchase['quantity'];

        //             if ($qtyToProcess > 0 && $purchaseQty > 0) {
        //                 $unitsProcessed = min($qtyToProcess, $purchaseQty);

        //                 if ($transaction === $purchase) {
        //                     // For sales transactions
        //                     $profit += $unitsProcessed * ($rate - $purchase['rate_unit']);
        //                 } else {
        //                     // For return transactions
        //                     $profit -= $unitsProcessed * ($rate - $purchase['rate_unit']);
        //                 }

        //                 $purchaseInvoice[$purchaseKey]['quantity'] -= $unitsProcessed;

        //                 $qtyToProcess -= $unitsProcessed;
        //             }
        //         }

        //         unset($purchase);

        //         $profits[$transaction['id']] = $profit;
        //         $transaction['profit'] = $profit;
        //     }
        // }


        // dd($salesInvoice,$salesReturn,$purchaseReturn);

        foreach ($purchaseInvoices as $purchaseKey => $remainingPurchase) {
            $remainingPurchaseQty[$purchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $remainingPurchaseRate[$purchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];

        }
        // dd($remainingPurchaseQty);
        foreach ($obPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $obRemainingPurchaseQty[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $obRemainingPurchaseRate[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        foreach ($cbPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $cbRemainingPurchaseQty[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $cbRemainingPurchaseRate[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        $totalRemainingPurchaseQty = array_sum($remainingPurchaseQty);
        $totalRemainingPurchaseRate = array_sum($remainingPurchaseRate);
        $totalObRemainingPurchaseQty = array_sum($obRemainingPurchaseQty);
        $totalObRemainingPurchaseRate = array_sum($obRemainingPurchaseRate);
        $totalcbRemainingPurchaseQty = array_sum($cbRemainingPurchaseQty);
        $totalcbRemainingPurchaseRate = array_sum($cbRemainingPurchaseRate);

        // $concatenatedData = array_merge($openingBalanceForInventory, $originalPurchaseInvoice, $salesInvoice);

        $originalPurchaseInvoice = collect($purchaseInvoices);
        $originalSalesInvoice = collect($salesInvoices);
        $originalSalesReturn = collect($salesReturns);
        $originalPurchaseReturn = collect($purchaseReturns);

        $allData = $openingBalanceForInventory
        ->concat($originalPurchaseInvoice)
        ->concat($originalSalesInvoice)
        ->concat($originalSalesReturn)
        ->concat($originalPurchaseReturn);

            // dd($allData);

        // dd($openingBalanceForInventory,$originalPurchaseInvoice,$salesInvoice);

        return view('crusher.reports.particular-item-query', compact('item', 'salesInvoice','openingBalanceForInventory','originalPurchaseInvoice', 'from_date', 'to_date', 'item_stock','profits','totalRemainingPurchaseQty','totalRemainingPurchaseRate','totalObRemainingPurchaseQty','totalObRemainingPurchaseRate','totalcbRemainingPurchaseQty','totalcbRemainingPurchaseRate','salesReturn','purchaseReturn','totalClosingQuantity','totalClosingTotal','allData'));
    }
    public function particularItemQuery11(Request $request)
    {
        $from_date = $request->old('from_date');
        $to_date = $request->old('to_date');
        $item_stock = $request->old('item_stock');
        $currentYearFirstDate = date("2003-01-01");
        $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));
        $item = ItemName::find($item_stock);

        if (!$item) {
            abort(404);
        }

        $salesInvoice = AdminSalesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();

        $originalPurchaseInvoice = AdminPurchaesInvoice::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNotNull('invoice_no')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $openingBalanceForInventory = OpeningBalance::with([
                'customer' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'supplier' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'StaffAndSalesman' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'Expense' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                },
                'AdminOtherAccount' => function ($query) {
                    $query->where('branch_id', session()->get('selected_branch'));
                }
            ])
            ->where('branch_id', session()->get('selected_branch'))
            ->where('item_id', $item_stock)
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNotNull('invoice_no')
            // ->groupBy('invoice_no')
            ->orderBy('invoice_no')
            ->get();
        $obSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
        ])
        ->where('branch_id', session()->get('selected_branch'))
        ->where('item_id', $item_stock)
        ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
        ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
        // ->groupBy('invoice_no')
        ->orderBy('invoice_no')
        ->get();
         $obPurchaseInvoice = AdminPurchaesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
        ])
         ->where('branch_id', session()->get('selected_branch'))
         ->where('item_id', $item_stock)
         ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
         ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
         ->whereNotNull('invoice_no')
         ->orderBy('invoice_no')
         ->get();
        $cbSalesInvoice = AdminSalesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
        ])
        ->where('branch_id', session()->get('selected_branch'))
        ->where('item_id', $item_stock)
        ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
        ->where('date', '<=', $from_date . ' 23:59:59')
        // ->groupBy('invoice_no')
        ->orderBy('invoice_no')
        ->get();
         $cbPurchaseInvoice = AdminPurchaesInvoice::with([
            'customer' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'supplier' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'StaffAndSalesman' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'Expense' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            },
            'AdminOtherAccount' => function ($query) {
                $query->where('branch_id', session()->get('selected_branch'));
            }
        ])
         ->where('branch_id', session()->get('selected_branch'))
         ->where('item_id', $item_stock)
         ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
         ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
         ->whereNotNull('invoice_no')
         ->orderBy('invoice_no')
         ->get();

        $salesInvoice = $salesInvoice->toArray();
        $openingBalanceForInventory = $openingBalanceForInventory->toArray();
        $originalPurchaseInvoice = $originalPurchaseInvoice->toArray();

        $obSalesInvoice = $obSalesInvoice->toArray();
        $obPurchaseInvoice = $obPurchaseInvoice->toArray();

        $cbSalesInvoice = $cbSalesInvoice->toArray();
        $cbPurchaseInvoice = $cbPurchaseInvoice->toArray();



        $profits = [];
        $remainingPurchaseQty = [];
        $remainingPurchaseRate = [];
        $obRemainingPurchaseQty = [];
        $obRemainingPurchaseRate = [];
        $cbRemainingPurchaseQty = [];
        $cbRemainingPurchaseRate = [];

        $cbPurchaseInvoices = $cbPurchaseInvoice;

        foreach ($cbSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($cbPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $cbPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }
        $obPurchaseInvoices = $obPurchaseInvoice;

        foreach ($obSalesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($obPurchaseInvoices as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $obPurchaseInvoices[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }

        // $purchaseInvoice = $openingBalanceForInventory + $originalPurchaseInvoice;
        $purchaseInvoice = array_merge($openingBalanceForInventory, $originalPurchaseInvoice);

        foreach ($salesInvoice as $key => &$sale) {
            $qtyToSell = $sale['quantity'];
            $rate = $sale['rate_unit'];
            $profit = 0;

            foreach ($purchaseInvoice as $purchaseKey => &$purchase) {
                $purchaseQty = $purchase['quantity'];

                if ($qtyToSell > 0 && $purchaseQty > 0) {
                    $unitsSold = min($qtyToSell, $purchaseQty);

                    $profit += $unitsSold * ($rate - $purchase['rate_unit']);

                    $purchaseInvoice[$purchaseKey]['quantity'] -= $unitsSold;

                    $qtyToSell -= $unitsSold;
                }
            }

            unset($purchase);

            $profits[$sale['id']] = $profit;
            $sale['profit'] = $profit;

        }

        foreach ($purchaseInvoice as $purchaseKey => $remainingPurchase) {
            $remainingPurchaseQty[$purchaseInvoice[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $remainingPurchaseRate[$purchaseInvoice[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];

        }

        foreach ($obPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $obRemainingPurchaseQty[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $obRemainingPurchaseRate[$obPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        foreach ($cbPurchaseInvoices as $purchaseKey => $remainingPurchase) {
            $cbRemainingPurchaseQty[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'];
            $cbRemainingPurchaseRate[$cbPurchaseInvoices[$purchaseKey]['id']] = $remainingPurchase['quantity'] * $remainingPurchase['rate_unit'];
        }

        $totalRemainingPurchaseQty = array_sum($remainingPurchaseQty);
        $totalRemainingPurchaseRate = array_sum($remainingPurchaseRate);
        $totalObRemainingPurchaseQty = array_sum($obRemainingPurchaseQty);
        $totalObRemainingPurchaseRate = array_sum($obRemainingPurchaseRate);
        $totalcbRemainingPurchaseQty = array_sum($cbRemainingPurchaseQty);
        $totalcbRemainingPurchaseRate = array_sum($cbRemainingPurchaseRate);

        $concatenatedData = array_merge($openingBalanceForInventory, $originalPurchaseInvoice, $salesInvoice);

        // dd($concatenatedData,$totalRemainingPurchaseQty,$totalRemainingPurchaseRate);
        // dd($concatenatedData,$remainingPurchaseQty,$remainingPurchaseRate,$totalRemainingPurchaseQty,$totalRemainingPurchaseRate,$totalObRemainingPurchaseQty,$totalObRemainingPurchaseRate);

        return view('crusher.reports.particular-item-query', compact('item', 'salesInvoice','openingBalanceForInventory','originalPurchaseInvoice', 'from_date', 'to_date', 'item_stock', 'concatenatedData','profits','totalRemainingPurchaseQty','totalRemainingPurchaseRate','totalObRemainingPurchaseQty','totalObRemainingPurchaseRate','totalcbRemainingPurchaseQty','totalcbRemainingPurchaseRate'));
    }


}
