<?php

namespace App\Http\Controllers\Transaction;
use App\Http\Controllers\Controller;
use App\WarehouseStockTransfer;
use App\WarehouseStockTransferItem;
use Illuminate\Http\Request;

use Session;
use DB;
use Auth;
use Carbon\Carbon;
use App\Supplier;
use App\Services\Utils;
use App\Services\Slug;
use App\WareHouse;
use App\PurchaseInvoice;
use App\PurchaseInvoiceItem;
use App\PurchaseSalesTransferStockTrack;
use App\WareHouseTrack;
use GuzzleHttp\Promise\Utils as PromiseUtils;

class WarehouseStockTransferController extends Controller
{
    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('warehouse-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $warehouse_stock_transfers = WarehouseStockTransfer::withTrashed()->where('location_id', $location_id)->orderBy('created_at','DESC')->paginate(100);
        return view('user.transactions.warehouse_stock_transfer.index', compact('warehouse_stock_transfers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('warehouse-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $latest_warehouse_stock_transfer = WarehouseStockTransfer::where('location_id', $location_id)->withTrashed()->latest()->first();
        if($latest_warehouse_stock_transfer){
            $warehouse_stock_transfer_no = $latest_warehouse_stock_transfer-> warehouse_stock_transfer_no + 1;
        }else{
            $warehouse_stock_transfer_no = 1;
        }
        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        // $items = [];
        // $purchase_invoices = PurchaseInvoice::with('items')->where('location_id', $location_id)->get();
        // foreach ($purchase_invoices as $key => $purchase_invoice) {
        //     foreach ($purchase_invoice->items as $key => $item) {
        //         $items[] = $item;
        //     }
        // }
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();

        return view('user.transactions.warehouse_stock_transfer.create',compact('warehouse_stock_transfer_no', 'warehouses', 'items'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $warehouse_stock_transfer = new WarehouseStockTransfer();
            $warehouse_stock_transfer->location_id = $location_id;
            $warehouse_stock_transfer->warehouse_stock_transfer_no = $request-> warehouse_stock_transfer_no;
            $warehouse_stock_transfer->date = $request-> date;
            $warehouse_stock_transfer->save();

            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $warehouse_stock_transfer_item = new WarehouseStockTransferItem();
                $warehouse_stock_transfer_item-> warehouse_stock_transfer_id = $warehouse_stock_transfer-> id;
                $warehouse_stock_transfer_item-> from_wareHouse = $request->from_warehouse[$key];
                $warehouse_stock_transfer_item-> imei_serial_no = $request->imei_serial_no[$key];
                $warehouse_stock_transfer_item-> to_wareHouse = $request->to_wareHouse[$key];
                $warehouse_stock_transfer_item-> remarks = $request->remarks[$key];
                $warehouse_stock_transfer_item-> save();

                // $purchase_invoice_item = PurchaseInvoiceItem::Find($request->item_id[$key]);
                // $purchase_invoice_item->warehouse_id = $request->to_wareHouse[$key];
                // $purchase_invoice_item->save();

                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    $purchase_sales_transfer_stock_track->warehouse_id = $request->to_wareHouse[$key];
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            DB::commit();
            Session::flash('alert-success','Warehouse Stock Transfer successfully');
            return redirect('/transactions/warehouse-stock-transfers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\WarehouseStockTransfer  $warehouseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function show(WarehouseStockTransfer $warehouseStockTransfer)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\WarehouseStockTransfer  $warehouseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = Auth::user();
        if (!$user->can('edit-warehouse-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        // $warehouse_stock_transfer = WarehouseStockTransfer::with('items')->where('id', $id)->first();
        $warehouse_stock_transfer = WarehouseStockTransfer::with('items.fromWarehouse', 'items.toWarehouse', 'items.selectedItem')->where('id', $id)->first();
        // return $warehouse_stock_transfer->items;
        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        // $purchase_invoices = PurchaseInvoice::with('items')->where('location_id', $location_id)->get();
        // foreach ($purchase_invoices as $key => $purchase_invoice) {
        //     foreach ($purchase_invoice->items as $key => $item) {
        //         $items[] = $item;
        //     }
        // }
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();
        return view('user.transactions.warehouse_stock_transfer.edit',compact('warehouse_stock_transfer', 'warehouses', 'items'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\WarehouseStockTransfer  $warehouseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $warehouse_stock_transfer = WarehouseStockTransfer::where('id', $id)->first();
            $warehouse_stock_transfer->location_id = $location_id;
            $warehouse_stock_transfer->warehouse_stock_transfer_no = $request-> warehouse_stock_transfer_no;
            $warehouse_stock_transfer->date = $request-> date;
            $warehouse_stock_transfer->save();

            // WarehouseStockTransferItem::where('warehouse_stock_transfer_id', $id)->forcedelete();
            $transfer_items = WarehouseStockTransferItem::where('warehouse_stock_transfer_id', $id)->get();
            foreach ($transfer_items as $item) {
                $stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
                $stock_track->warehouse_id = $item->from_wareHouse;
                $stock_track->save();

                $item->forcedelete();
            }

            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $warehouse_stock_transfer_item = new WarehouseStockTransferItem();
                $warehouse_stock_transfer_item-> warehouse_stock_transfer_id = $warehouse_stock_transfer-> id;
                $warehouse_stock_transfer_item-> from_wareHouse = $request->from_warehouse[$key];
                $warehouse_stock_transfer_item-> imei_serial_no = $request->imei_serial_no[$key];
                $warehouse_stock_transfer_item-> to_wareHouse = $request->to_wareHouse[$key];
                $warehouse_stock_transfer_item-> remarks = $request->remarks[$key];
                $warehouse_stock_transfer_item-> save();

                // $purchase_invoice_item = PurchaseInvoiceItem::Find($request->item_id[$key]);
                // $purchase_invoice_item->warehouse_id = $request->to_wareHouse[$key];
                // $purchase_invoice_item->save();
                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    $purchase_sales_transfer_stock_track->warehouse_id = $request->to_wareHouse[$key];
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            DB::commit();
            Session::flash('alert-success','Warehouse Stock Transfer successfully');
            return redirect('/transactions/warehouse-stock-transfers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    public function viewDetails($id){
        $user = Auth::user();
        if (!$user->can('warehouse-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $warehouse_stock_transfer = WarehouseStockTransfer::with('items.fromWarehouse', 'items.toWarehouse', 'items.selectedItem')->where('id', $id)->first();

        return view('user.transactions.warehouse_stock_transfer.details',compact('warehouse_stock_transfer'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\WarehouseStockTransfer  $warehouseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function destroy(WarehouseStockTransfer $warehouseStockTransfer)
    {
        //
    }

    public function purchaseInvoiceItem($imei_serial_no){
        $location_id = $this->getLocationId();
        $item = PurchaseSalesTransferStockTrack::with('name','unit')->where('imei_serial_no', $imei_serial_no)->Where('location_id', $location_id)->first();
        $from_warehouse = WareHouse::Where('id', $item->warehouse_id)->first();
        $to_warehouse = WareHouse::Where('id', '!=', $from_warehouse->id)->Where('location_id', $location_id)->get();
        // dd($item->warehouse);
        if($item) {
            return response()->json(['status' => 'success', 'data' => $item, 'from_warehouse' => $from_warehouse->name, 'to_warehouse' => $to_warehouse]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function softdelete($id)
    {
        $user = Auth::user();
        if (!$user->can('cancel-warehouse-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $warehouse_stock_transfer = WarehouseStockTransfer::Find($id);
        $warehouse_stock_transfer->delete();
        $warehouse_stock_transfer_items = WarehouseStockTransferItem::Where('warehouse_stock_transfer_id', $id)->get();
        foreach ($warehouse_stock_transfer_items as $item) {
            $stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
            $stock_track->warehouse_id = $item->from_wareHouse;
            $stock_track->save();

            $item->delete();
        }
        Session::flash('alert-success','Warehouse Stock Transfer Cancelled successfully');
        return redirect('/transactions/warehouse-stock-transfers');
    }
}
