<?php

namespace App\Http\Controllers\Master;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use Auth;
use DB;
use Storage;
use Session;
use Carbon\Carbon;
use App\Services\Utils;
use App\Services\Slug;
use App\ItemGroup;

class ItemGroupController extends Controller
{

    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('item-group-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $item_groups = ItemGroup::Where('location_id', $location_id)->orderBy('created_at','DESC')->paginate(100);
        return view('user.masters.item_groups.index', compact('item_groups'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('item-group-master')) {
            abort(403, 'Unauthorized action.');
        }

        return view('user.masters.item_groups.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $location_id = $this->getLocationId();

        foreach ($request->name as $key => $name) {
            $item = ItemGroup::Where('name', $request->name[$key])->where('location_id', $location_id)->first();
            if ($item) {
                Session::flash('alert-danger', '' .$request->name[$key]. ' Item Group Name Already Exists');
                return redirect('/masters/item-groups');
            }else
                $item_group = new ItemGroup();
                $item_group->location_id = $location_id;
                $item_group->name = $request->name[$key];
                $item_group->slug = $this->slug->createSlug('item_group', $request->name[$key]);
                $item_group->status = 'active';
                $item_group->save();
        }

        Session::flash('alert-success', 'Item Group created successfully');
        return redirect('/masters/item-groups');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\ItemGroup  $item_group
     * @return \Illuminate\Http\Response
     */
    public function show(ItemGroup $item_group)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\ItemGroup  $item_group
     * @return \Illuminate\Http\Response
     */
    public function edit($item_group_id)
    {
        $user = Auth::user();
        if (!$user->can('item-group-master')) {
            abort(403, 'Unauthorized action.');
        }

        $item_group = ItemGroup::find($item_group_id);
        return view('user.masters.item_groups.edit', compact('item_group'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\ItemGroup  $item_group
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $item_group_id)
    {
        $location_id = $this->getLocationId();
        $group_name = ItemGroup::find($item_group_id);
        $previous_name = $group_name->name;
        if ($previous_name != $request->name) {
            $item = ItemGroup::Where('name', $request->name)->where('location_id', $location_id)->first();
            if ($item) {
                Session::flash('alert-danger', '' .$request->name. ' Group Name Already Exists');
                return redirect('/masters/item-groups');
            }
            $group_name->name = $request->name;

            $group_name->save();

            Session::flash('alert-success', 'Item Group Name updated successfully');
            return redirect('/masters/item-groups');

        }
        else
        {
        $group_name->name = $request->name;
        $group_name->save();

        Session::flash('alert-success', 'Item Group Name updated successfully');
        return redirect('/masters/item-groups');

        }



        // $item_group = ItemGroup::find($item_group_id);
        // $item_group->name = $request->name;
        // $item_group->slug = $this->slug->createSlug('item_group', $request->name);
        // $item_group->save();
        // Session::flash('alert-success', 'Item Group updated successfully');
        // return redirect('/masters/item-groups');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\ItemGroup  $item_group
     * @return \Illuminate\Http\Response
     */
    public function destroy($item_group_id)
    {
        $item_group = ItemGroup::findOrFail($item_group_id);
        $item_group->delete();
        Session::flash('alert-success', 'Item Group deleted successfully');
        return redirect('/masters/item-groups');
    }

    public function softdelete($item_group_id)
    {
        $item_group = ItemGroup::findOrFail($item_group_id);
        $item_group->forceDelete();
        Session::flash('alert-success', 'Item Group deleted successfully');
        return redirect('/masters/item-groups');
    }
}
