<?php

namespace App\Http\Controllers\Transaction\CountryLocationWiseTransfer;
use App\Http\Controllers\Controller;
use App\CountryLocationWiseStockTransfer;
use App\CountryLocationWiseStockTransferItem;
use App\ItemName;
use Illuminate\Http\Request;

use Session;
use DB;
use Auth;
use Carbon\Carbon;
use App\Supplier;
use App\Services\Utils;
use App\Services\Slug;
use App\WareHouse;
use App\PurchaseInvoice;
use App\Location;
use App\Country;
use App\PurchaseSalesTransferStockTrack;
use App\WareHouseTrack;

class StockTransferController extends Controller
{
    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('country-location-wise-stock-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $country_location_wise_stock_transfers = CountryLocationWiseStockTransfer::withTrashed()->where('location_id', $location_id)->orderBy('created_at','DESC')->paginate(100);
        return view('user.transactions.country_location_wise_transfer.stock_transfer.index', compact('country_location_wise_stock_transfers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('country-location-wise-stock-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        // $current_country = Location::Where('id', $location_id)->first();
        // $countries = Country::Where('id', '!=', $current_country->country->id)->get();
        $countries = Country::all();
        $locations = Location::all();
        $latest_country_location_wise_stock_transfers = CountryLocationWiseStockTransfer::where('location_id', $location_id)->withTrashed()->latest()->first();
        if($latest_country_location_wise_stock_transfers){
            $country_location_wise_stock_transfer_no = $latest_country_location_wise_stock_transfers-> country_location_wise_stock_transfer_no + 1;
        }else{
            $country_location_wise_stock_transfer_no = 1;
        }
        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $location = Location::where(['id' => $location_id])->first()->name;
        $country = Location::with('country')->where(['id' => $location_id])->first();

        $country_id = $country->country->id;
        $country = $country->country->name;
        // $items = [];
        // $purchase_invoices = PurchaseInvoice::with('items')->where('location_id', $location_id)->get();
        // foreach ($purchase_invoices as $key => $purchase_invoice) {
        //     foreach ($purchase_invoice->items as $key => $item) {
        //         $items[] = $item;
        //     }
        // }
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();
        return view('user.transactions.country_location_wise_transfer.stock_transfer.create',compact('country_location_wise_stock_transfer_no', 'countries', 'locations',  'location', 'country_id', 'country', 'warehouses', 'items'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $location = Location::where(['id' => $location_id])->first()->id;
            $country = Location::with('country')->where(['id' => $location_id])->first()->country->id;
            $location_id = $this->getLocationId();
            $country_location_wise_stock_transfer = new CountryLocationWiseStockTransfer();
            $country_location_wise_stock_transfer->location_id = $location_id;
            $country_location_wise_stock_transfer->country_location_wise_stock_transfer_no = $request-> country_location_wise_stock_transfer_no;
            $country_location_wise_stock_transfer->date = $request-> date;
            $country_location_wise_stock_transfer->from_country = $country;
            $country_location_wise_stock_transfer->from_location = $location;
            $country_location_wise_stock_transfer->to_country = $request-> to_country;
            $country_location_wise_stock_transfer->to_location = $request-> to_location;
            $country_location_wise_stock_transfer->currency_rate = $request->currency_rate;
            $country_location_wise_stock_transfer->multiply_divide = $request->operation;
            $country_location_wise_stock_transfer->save();

            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $country_location_wise_stock_transfer_item = new CountryLocationWiseStockTransferItem();
                $country_location_wise_stock_transfer_item-> country_location_wise_stock_transfer_id = $country_location_wise_stock_transfer-> id;
                $country_location_wise_stock_transfer_item-> from_wareHouse = $request->from_wareHouse[$key];
                $country_location_wise_stock_transfer_item-> imei_serial_no = $request->imei_serial_no[$key];
                $country_location_wise_stock_transfer_item-> to_wareHouse = $request->to_wareHouse[$key];
                $country_location_wise_stock_transfer_item-> remarks = $request->remarks[$key];
                $country_location_wise_stock_transfer_item-> save();

                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    if ($request->operation == "multiply") {
                        $rate_per_quantity = $request->currency_rate * $purchase_sales_transfer_stock_track->rate_per_quantity;
                        $amount = $request->currency_rate * $purchase_sales_transfer_stock_track->amount;
                    }elseif ($request->operation == "divide") {
                        $rate_per_quantity = $purchase_sales_transfer_stock_track->rate_per_quantity / $request->currency_rate;
                        $amount = $purchase_sales_transfer_stock_track->amount / $request->currency_rate;
                    }
                    $purchase_sales_transfer_stock_track->location_id = $request-> to_location;
                    $purchase_sales_transfer_stock_track->from_location_id = $location;
                    $purchase_sales_transfer_stock_track->warehouse_id = $request-> to_wareHouse[$key];
                    $purchase_sales_transfer_stock_track->form_item_name_id =  $purchase_sales_transfer_stock_track->item_name_id;
                    $purchase_sales_transfer_stock_track->item_name_id = $request-> to_item_name[$key];
                    $purchase_sales_transfer_stock_track->rate_per_quantity = $rate_per_quantity;
                    $purchase_sales_transfer_stock_track->amount = $amount;
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            DB::commit();
            Session::flash('alert-success','Country Location Wise Stock Transfer successfully');
            return redirect('/transactions/country-location-wise-transfer/stock-transfers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\CountryLocationWiseStockTransfer  $countryLocationWiseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function show(CountryLocationWiseStockTransfer $countryLocationWiseStockTransfer)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\CountryLocationWiseStockTransfer  $countryLocationWiseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = Auth::user();
        if (!$user->can('edit-country-location-wise-stock-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $countries = Country::all();
        $locations = Location::all();
        $country_location_wise_stock_transfer = CountryLocationWiseStockTransfer::with('items.selectedItem', 'items.toWarehouse', 'items.fromWarehouse')->where('id', $id)->first();
        // dd($country_location_wise_stock_transfer->multiply_divide);
        $selected_location = $country_location_wise_stock_transfer->to_location;
        $selected_locations = Location::Where('country_id', $country_location_wise_stock_transfer->to_country)->get();
        $latest_country_location_wise_stock_transfers = CountryLocationWiseStockTransfer::where('location_id', $location_id)->latest()->first();
        if($latest_country_location_wise_stock_transfers){
            $country_location_wise_stock_transfer_no = $latest_country_location_wise_stock_transfers-> country_location_wise_stock_transfer_no + 1;
        }else{
            $country_location_wise_stock_transfer_no = 1;
        }
        // $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($selected_location) {
        //     $q->where('location_id', $selected_location);}])->Where('user_id', auth()->user()->id)->get();

        $from_warehouses = WareHouse::Where('location_id', $selected_location)->get();

        // dd($warehouses);

        $location = Location::where(['id' => $location_id])->first()->name;
        $country = Location::with('country')->where(['id' => $location_id])->first()->country->name;

        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();
        return view('user.transactions.country_location_wise_transfer.stock_transfer.edit',compact('country_location_wise_stock_transfer', 'country_location_wise_stock_transfer_no', 'countries', 'locations',  'location', 'country', 'from_warehouses', 'items', 'selected_locations'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\CountryLocationWiseStockTransfer  $countryLocationWiseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        dd($request->all());
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $location = Location::where(['id' => $location_id])->first()->id;
            $country = Location::with('country')->where(['id' => $location_id])->first()->country->id;
            $location_id = $this->getLocationId();
            $country_location_wise_stock_transfer = CountryLocationWiseStockTransfer::where('id', $id)->first();
            $previous_currency_rate = $country_location_wise_stock_transfer->currency_rate;
            $previous_multiply_divide = $country_location_wise_stock_transfer->multiply_divide;
            $previous_from_location = $country_location_wise_stock_transfer->from_location;
            $country_location_wise_stock_transfer->location_id = $location_id;
            $country_location_wise_stock_transfer->country_location_wise_stock_transfer_no = $request-> country_location_wise_stock_transfer_no;
            $country_location_wise_stock_transfer->date = $request-> date;
            $country_location_wise_stock_transfer->from_country = $country;
            $country_location_wise_stock_transfer->from_location = $location;
            $country_location_wise_stock_transfer->to_country = $request-> to_country;
            $country_location_wise_stock_transfer->to_location = $request-> to_location;
            $country_location_wise_stock_transfer->multiply_divide = $request->operation;
            $country_location_wise_stock_transfer->save();

            // CountryLocationWiseStockTransferItem::where('country_location_wise_stock_transfer_id', $id)->forcedelete();
            $location_stock_transfer_items = CountryLocationWiseStockTransferItem::where('country_location_wise_stock_transfer_id', $id)->get();
            foreach ($location_stock_transfer_items as $item) {
                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
                if ($purchase_sales_transfer_stock_track) {
                    if ($previous_multiply_divide == "divide") {
                        $rate_per_quantity = $previous_currency_rate * $purchase_sales_transfer_stock_track->rate_per_quantity;
                        $amount = $previous_currency_rate * $purchase_sales_transfer_stock_track->amount;
                    }elseif ($previous_multiply_divide == "multiply") {
                        $rate_per_quantity = $purchase_sales_transfer_stock_track->rate_per_quantity / $previous_currency_rate;
                        $amount = $purchase_sales_transfer_stock_track->amount / $previous_currency_rate;
                    }
                    $purchase_sales_transfer_stock_track->location_id = $previous_from_location;
                    $purchase_sales_transfer_stock_track->warehouse_id = $item-> from_wareHouse;
                    $purchase_sales_transfer_stock_track->rate_per_quantity = $rate_per_quantity;
                    $purchase_sales_transfer_stock_track->amount = $amount;
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found");
                }

                $item->forcedelete();
            }


            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $country_location_wise_stock_transfer_item = new CountryLocationWiseStockTransferItem();
                $country_location_wise_stock_transfer_item-> country_location_wise_stock_transfer_id = $country_location_wise_stock_transfer-> id;
                $country_location_wise_stock_transfer_item-> from_wareHouse = $request->from_wareHouse[$key];
                $country_location_wise_stock_transfer_item-> imei_serial_no = $request->imei_serial_no[$key];
                $country_location_wise_stock_transfer_item-> to_wareHouse = $request->to_wareHouse[$key];
                $country_location_wise_stock_transfer_item-> remarks = $request->remarks[$key];
                $country_location_wise_stock_transfer_item-> save();

                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    if ($request->operation == "multiply") {
                        $rate_per_quantity = $request->currency_rate * $purchase_sales_transfer_stock_track->rate_per_quantity;
                        $amount = $request->currency_rate * $purchase_sales_transfer_stock_track->amount;
                    }elseif ($request->operation == "divide") {
                        $rate_per_quantity = $purchase_sales_transfer_stock_track->rate_per_quantity / $request->currency_rate;
                        $amount = $purchase_sales_transfer_stock_track->amount / $request->currency_rate;
                    }
                    $purchase_sales_transfer_stock_track->location_id = $request-> to_location;
                    $purchase_sales_transfer_stock_track->warehouse_id = $request-> to_wareHouse[$key];
                    $purchase_sales_transfer_stock_track->rate_per_quantity = $rate_per_quantity;
                    $purchase_sales_transfer_stock_track->amount = $amount;
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            DB::commit();
            Session::flash('alert-success','Country Location Wise Stock Transfer successfully');
            return redirect('/transactions/country-location-wise-transfer/stock-transfers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\CountryLocationWiseStockTransfer  $countryLocationWiseStockTransfer
     * @return \Illuminate\Http\Response
     */
    public function destroy(CountryLocationWiseStockTransfer $countryLocationWiseStockTransfer)
    {
        //
    }

    public function softdelete($id)
    {
        $user = Auth::user();
        if (!$user->can('cancel-country-location-wise-stock-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $country_location_wise_stock_transfer = CountryLocationWiseStockTransfer::Find($id);
        // $country_location_wise_stock_transfer->delete();
        $country_location_wise_stock_transfer_item = CountryLocationWiseStockTransferItem::Where('country_location_wise_stock_transfer_id', $id)->get();
        foreach ($country_location_wise_stock_transfer_item as $item) {
            $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
            if ($purchase_sales_transfer_stock_track) {
                if ($country_location_wise_stock_transfer->multiply_divide == "divide") {
                    $rate_per_quantity = $country_location_wise_stock_transfer->currency_rate * $purchase_sales_transfer_stock_track->rate_per_quantity;
                    $amount = $country_location_wise_stock_transfer->currency_rate * $purchase_sales_transfer_stock_track->amount;
                }elseif ($country_location_wise_stock_transfer->multiply_divide == "multiply") {
                    $rate_per_quantity = $purchase_sales_transfer_stock_track->rate_per_quantity / $country_location_wise_stock_transfer->currency_rate;
                    $amount = $purchase_sales_transfer_stock_track->amount / $country_location_wise_stock_transfer->currency_rate;
                }
                $purchase_sales_transfer_stock_track->location_id = $country_location_wise_stock_transfer-> from_location;
                $purchase_sales_transfer_stock_track->warehouse_id = $item-> from_wareHouse;
                $purchase_sales_transfer_stock_track->rate_per_quantity = $rate_per_quantity;
                $purchase_sales_transfer_stock_track->amount = $amount;
                $purchase_sales_transfer_stock_track->save();
            }else{
                return redirect()->back()->withErrors("IMEI Not Found");
            }

            $item->delete();
        }
        $country_location_wise_stock_transfer->delete();

        Session::flash('alert-success','Country Location Wise Stock Transfer Cancelled successfully');
        return redirect('/transactions/country-location-wise-transfer/stock-transfers');
    }

    public function countryLocationsStock_transfer($country_id){
        $location_id = $this->getLocationId();
        $locations = Location::where('country_id', $country_id)->Where('id', '!=', $location_id)->get();
        $to_warehouse = [];
        foreach ($locations as $location) {
            $to_warehouse[] = Warehouse::where('location_id', $location->id)->first();
        }
        if($locations) {
            return response()->json(['status' => 'success', 'data' => $locations, 'to_warehouse' => $to_warehouse]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function countryLocationsStock_transfer_warehouse($location_id){
        $warehouses = WareHouse::where('location_id', $location_id)->get();
        if($warehouses) {
            return response()->json(['status' => 'success', 'to_warehouse' => $warehouses]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function countryLocationsStock_transfer_warehouse_to_item($location_id){
        $item_names = ItemName::Where('location_id', $location_id)->get();
        if($item_names) {
            return response()->json(['status' => 'success', 'to_item_name' => $item_names]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

}
