@php
    use App\Branches;
    use Carbon\Carbon;

    $selectedBranchId = session('selected_branch');

    $branche = Branches::where('id', $selectedBranchId)->first();

    $branchSoftware = $branche ? $branche->software : 'Software not found';

    $expire = false;
    $leniencyExpire = false;
    $status = false;
    if (!empty($selectedBranchId)) {
        $branch = Branches::find($selectedBranchId);
        $now = Carbon::parse(now())->format('Y-m-d');
        $branchExpireDate = Carbon::parse($branch->expiry_date);
        $leniency = $branch->leniency;
        if ($branchExpireDate->addDays($leniency)->lte($now)) {
            $expire = true;
            if (!$branch->vouchers->isEmpty()) {
                foreach ($branch->vouchers as $voucher) {
                    if ($voucher->created_at->gte($branchExpireDate)) {
                        $expire = false;
                    }
                }
            }
        }

        $status = $branch->status;
    }

    // Merge notifications and reminders collections and add a 'type' column
    $notifications = auth()
        ->user()
        ->notifications()
        ->with('notification')
        ->orderBy('id', 'desc')
        ->get();

    $reminders = auth()
        ->user()
        ->reminders()
        ->with('reminder')
        ->orderBy('id', 'desc')
        ->get();

    // Rename 'created_at' to 'timestamp' and add 'type' column
    $notifications = $notifications->map(function ($notification) {
        $notification['timestamp'] = $notification['created_at'];
        $notification['type'] = 'notification';
        return $notification;
    });

    $reminders = $reminders->map(function ($reminder) {
        $reminder['timestamp'] = $reminder['created_at'];
        $reminder['type'] = 'reminder';
        return $reminder;
    });

    // Merge both collections
    $mergedData = $notifications->concat($reminders);

    // Sort the merged collection by timestamp in descending order
    $mergedData = $mergedData->sortByDesc('timestamp');

@endphp

<!doctype html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <title>ACP</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta content="Premium Multipurpose Admin & Dashboard Template" name="description" />
    <meta content="Themesbrand" name="author" />
    <!-- App favicon -->
    <link rel="shortcut icon" href="{{ asset('assets/images/favicon.ico') }}">
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css" />

    <!-- jquery.vectormap css -->
    <link href="{{ asset('assets/libs/admin-resources/jquery.vectormap/jquery-jvectormap-1.2.2.css') }}"
        rel="stylesheet" type="text/css" />

    <!-- Bootstrap Css -->
    <link href="{{ asset('assets/css/bootstrap.min.css') }}" id="bootstrap-style" rel="stylesheet" type="text/css" />
    <!-- Icons Css -->
    <link href="{{ asset('assets/css/icons.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- App Css-->
    <link href="{{ asset('assets/css/app.min.css') }}" id="app-style" rel="stylesheet" type="text/css" />
    <link href="{{ asset('assets/css/custom.css') }}" rel="stylesheet" />
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/jquery.dataTables.css" />
    <link href="{{ asset('assets/css/jquery.multiselect.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ asset('assets/css/style.css') }}" rel="stylesheet" type="text/css" />
    <style>
        #sidebar-menu ul li a.waves-effect {
            /* Default text color */
            transition: color 0.3s;
            /* Add transition for smooth color change */
        }

        #sidebar-menu ul li a.waves-effect.active {
            /* Desired text color when active */
            color: #3b5de7;
        }

        #sidebar-menu ul li a.waves-effect.active i {
            /* Desired icon color when active */
            color: #3b5de7;
        }
        .td-drak-bg{
            background-color: #2e359412;
            color: gray;
        }
        .td-drak-light{
            background-color: #2e359412;
            color: gray;
        }
    </style>
</head>

<body data-layout="detached" data-topbar="colored">
    {{-- <div class="lds-dual-ring">
        <img class="loader-logo" src="{{ asset('assets/images/acp-loader-logo.png') }}" height="50" width="100"
            alt="Your Logo">
    </div> --}}
    <div class="containedffgdgfdr-fluid">
        <!-- Begin page -->
        <div id="layout-wrapper">

            <header id="page-topbar">
                <div class="navbar-header">
                    <div class="container-fluid">
                        <div class="float-right">
                            <div class="dropdown d-none d-lg-inline-block ml-1">
                                <button type="button" class="btn header-item noti-icon waves-effect"
                                    data-toggle="fullscreen">
                                    <i class="mdi mdi-fullscreen"></i>
                                </button>
                            </div>
                            <!-- Notification Panel -->
                            <div class="dropdown d-inline-block">
                                <button type="button" class="btn header-item noti-icon waves-effect"
                                    id="page-header-notifications-dropdown" data-toggle="dropdown" aria-haspopup="true"
                                    aria-expanded="false" onclick="updateNotificationsViewed()">
                                    <i class="mdi mdi-bell-outline"></i>
                                    <span
                                        class="badge badge-danger badge-pill">{{ $mergedData->where('is_viewed', 0)->count() }}</span>
                                </button>
                                <div class="dropdown-menu dropdown-menu-lg dropdown-menu-right p-0"
                                    aria-labelledby="page-header-notifications-dropdown">
                                    <!-- Header -->
                                    <div class="p-3">
                                        <div class="row align-items-center">
                                            <div class="col">
                                                <h6 class="m-0"> Notifications </h6>
                                            </div>
                                            <div class="col-auto">
                                                <a href="#!" class="small"> View All</a>
                                            </div>
                                        </div>
                                    </div>
                                    <!-- Notification Items -->
                                    <div data-simplebar style="max-height: 230px;">
                                        @forelse ($mergedData as $item)
                                            @php
                                                $title = optional($item->reminder)->title ?? optional($item->notification)->title;
                                                $description = optional($item->reminder)->description ?? optional($item->notification)->description;
                                                $isNotification = $item['type'] === 'notification';
                                                $link = $isNotification ? route('crusher.notifications.new_show', ['notification' => optional($item->notification)->id]) : route('crusher.reminders.new_show', ['reminder' => optional($item->reminder)->id]);
                                            @endphp
                                            <a href="{{ $link }}" class="text-reset notification-item">
                                                <div class="media">
                                                    <div class="avatar-xs mr-3">
                                                        <span
                                                            class="avatar-title bg-primary rounded-circle font-size-16">
                                                            <i class="bx bx-cart"></i>
                                                        </span>
                                                    </div>
                                                    <div class="media-body">
                                                        <h6 class="mt-0 mb-1">{{ $title }}</h6>
                                                        <div class="font-size-12 text-muted">
                                                            <p class="mb-1">{{ $description }}</p>
                                                            <p class="mb-0">
                                                                <i class="mdi mdi-clock-outline"></i>
                                                                {{ $item['timestamp']->diffForHumans() }}
                                                                ({{ $isNotification ? 'Notification' : 'Reminder' }})
                                                            </p>
                                                        </div>
                                                    </div>
                                                </div>
                                            </a>
                                        @empty
                                            <p>No notifications or reminders available.</p>
                                        @endforelse
                                    </div>
                                    <!-- View More Button -->
                                    <div class="p-2 border-top">
                                        <a class="btn btn-sm btn-link font-size-14 btn-block text-center"
                                            href="javascript:void(0)">
                                            <i class="mdi mdi-arrow-right-circle mr-1"></i> View More..
                                        </a>
                                    </div>
                                </div>
                            </div>

                            <div class="dropdown d-inline-block">
                                <button type="button" class="btn header-item waves-effect"
                                    id="page-header-user-dropdown" data-toggle="dropdown" aria-haspopup="true"
                                    aria-expanded="false">
                                    @php
                                        $user = App\User::where('id', session('uv_user_id'))->first();
                                    @endphp

                                    @if (!empty(($image = auth()->user()->image)))
                                        <img src="{{ asset('storage/app/public/' . $image) }}" alt=""
                                            class="avatar-md mx-auto rounded-circle">
                                    @else
                                        <img class="rounded-circle header-profile-user"
                                            src="{{ asset('assets/images/dp-profational.jpg') }}" alt="Header Avatar">
                                    @endif

                                    <span class="d-none d-xl-inline-block ml-1">{{ $user->name }}</span>
                                    <i class="mdi mdi-chevron-down d-none d-xl-inline-block"></i>
                                </button>

                                <div class="dropdown-menu dropdown-menu-right">
                                    <!-- item-->
                                    @if (!empty(session()->get('selected_branch')))
                                        <a class="dropdown-item"><i
                                                class="bx bx-calendar font-size-16 align-middle mr-1"></i>
                                            @if ($expire)
                                                <span class="text-danger">Expired
                                                    ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @elseif ($leniencyExpire)
                                                <span class="text-warning">Expiring Soon
                                                    ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @else
                                                <span class="text-success">Valid
                                                    ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @endif
                                        </a>
                                        <div class="dropdown-divider"></div>
                                        {{-- <div class="dropdown-item">
                                            @if ($expire)
                                                <span class="text-danger">Expired ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @elseif ($leniencyExpire)
                                                <span class="text-warning">Expiring Soon ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @else
                                                <span class="text-success">Valid ({{ $branchExpireDate->format('Y-m-d') }})</span>
                                            @endif
                                        </div> --}}
                                    @endif

                                    @if (!empty(session()->get('selected_branch')))
                                        <a class="dropdown-item" href="{{ route('crusher.branches.profile') }}"><i
                                                class="bx bx-user font-size-16 align-middle mr-1"></i> Profile</a>
                                    @endif
                                    @if (auth()->user()->role == 'admin')
                                        <a class="dropdown-item" href="{{ route('crusher.subadmins.index') }}">
                                            <i class="bx bx-user-plus bx-xs font-size-16 align-middle mr-1"></i> Create
                                            User
                                        </a>
                                    @endif

                                    <a class="dropdown-item d-block" href="{{ route('password.change') }}">
                                        <!-- <span class="badge badge-success float-right">11</span> -->
                                        <i class="bx bx-wrench font-size-16 align-middle mr-1"></i> Change Password</a>
                                    <!-- <a class="dropdown-item" href="#"><i
                                            class="bx bx-lock-open font-size-16 align-middle mr-1"></i> Lock screen</a> -->
                                    <div class="dropdown-divider"></div>
                                    <a class="dropdown-item text-danger" href="{{ url('logout') }}"><i
                                            class="bx bx-power-off font-size-16 align-middle mr-1 text-danger"></i>
                                        Logout</a>
                                </div>
                            </div>

                        </div>
                        <div>
                            <!-- LOGO -->
                            <div class="navbar-brand-box">
                            </div>

                            <button type="button"
                                class="btn btn-sm px-3 font-size-16 header-item toggle-btn waves-effect"
                                id="vertical-menu-btn">
                                <i class="fa fa-fw fa-bars"></i>
                            </button>
                            <button id="sidebarToggle" type="button"
                                class="btn btn-sm font-size-16 header-item waves-effect" id="vertical-menu-btn"
                                style="margin-left: 13.5rem;">
                                <i class="fa fa-fw fa-bars"></i>
                            </button>

                        </div>

                    </div>
                </div>
            </header>


            <!-- ========== Left Sidebar Start ========== -->
            <div class="vertical-menu" id="sidebar">

                <div class="h-100">

                    <div class="user-wid text-center py-4">
                        @if (!empty(($companyLogo = auth()->user()->company_logo)))
                            <img src="{{ asset('storage/app/public/' . $companyLogo) }}" class="logocust"
                                alt="logo">
                        @else
                            <img src="{{ asset('assets/images/acp-logo.png') }}" class="logocust" alt="logo">
                        @endif

                        <div class="user-img">
                            @if (!empty(($image = auth()->user()->image)))
                                <img src="{{ asset('storage/app/public/' . $image) }}" alt=""
                                    class="avatar-md mx-auto rounded-circle">
                            @else
                                <img src="{{ asset('assets/images/dp-profational.jpg') }}" alt=""
                                    class="avatar-md mx-auto rounded-circle">
                            @endif
                        </div>

                        <div class="mt-3">
                            <a href="#"
                                class="text-dark font-weight-medium font-size-16">{{ auth()->user()->name }}</a>
                            {{-- <p class="text-body mt-1 mb-0 font-size-13">Crusher</p> --}}
                            <p class="text-body mt-1 mb-0 font-size-13">{{ $branchSoftware }}</p>
                        </div>
                    </div>
                    {{-- <div class="user-wid text-center py-4">
                        <img src="{{ asset(auth()->user()->company_logo) }}" class="logocust" alt="logo">

                        <div class="user-img">
                            <img src="{{ asset(auth()->user()->image) }}" alt="" class="avatar-md mx-auto rounded-circle">
                        </div>

                        <div class="mt-3">
                            <a href="#" class="text-dark font-weight-medium font-size-16">{{ auth()->user()->name }}</a>
                            <p class="text-body mt-1 mb-0 font-size-13">Crusher</p>
                        </div>
                    </div> --}}


                    <!--- Sidemenu -->
                    <div id="sidebar-menu">
                        <!-- Left Menu Start -->
                        <ul class="metismenu list-unstyled" id="side-menu">
                            <li class="menu-title">Menu</li>

                            <li>
                                <a href="{{ url('crusher/index') }}" class="waves-effect">
                                    <i class="mdi mdi-airplay"></i>
                                    <span>Dashboard</span>
                                </a>
                            </li>

                            <li>
                                <a href="javascript: void(0);" class="has-arrow waves-effect"
                                    onclick="toggleSubMenu(this)">
                                    <i class="mdi mdi-flip-horizontal"></i>
                                    <span>Masters</span>
                                </a>
                                <ul class="sub-menu" aria-expanded="false" style="display: none;">
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'customers-account-master'))
                                        <li><a href="{{ url('crusher/master/customer_master/index') }}">Customers
                                                Master</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'expenses-account-master'))
                                        <li><a href="{{ route('crusher.expense.index') }}">Expenses
                                                Master</a>
                                        </li>
                                    @endif
                                    {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'warehouse-master'))
                                        <li><a href="{{ url('master/gatepass_master/index') }}">Gate Pass Master</a>
                                        </li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'item-group-master'))
                                        <li><a href="{{ route('crusher.item_groups.index') }}">Item Group
                                                Master</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'item-unit-master'))
                                        <li><a href="{{ route('crusher.item_units.index') }}">Item Unit Master</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'item-name-master'))
                                        <li><a href="{{ route('crusher.item_names.index') }}">Item Name Master</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'other-account-master'))
                                        <li><a href="{{ route('crusher.other_accounts.index') }}">Other Accounts
                                                Master</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'period-closing'))
                                        <li><a href="{{ route('crusher.period_closings.index') }}">Period
                                                Closing</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'suppliers-account-master'))
                                        <li><a href="{{ url('crusher/master/supplier_master/index') }}">Suppliers
                                                Master</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'staff-and-salesmen-account-master'))
                                        <li><a href="{{ url('crusher/master/staff_master/index') }}">Staff & Salesman
                                                Master</a>
                                        </li>
                                    @endif
                                    <li>
                                        <a href="javascript: void(0);" class="has-arrow waves-effect"
                                            onclick="toggleSubMenu(this)">
                                            <!-- <i class="mdi mdi-inbox-full"></i> -->
                                            <span>Term & Conditions</span>
                                        </a>
                                        <ul class="sub-menu" aria-expanded="false" style="display: none;">
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'delivery_note']) }}">Delivery
                                                        Note</a></li>
                                            @endif
                                            {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, ''))
                                                <li><a href="crusher-t-c-gate-pass.html">Gate Pass</a></li>
                                            @endif --}}
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'purchase_order']) }}">Purchase
                                                        Order</a></li>
                                            @endif
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'purchase_invoice']) }}">Purchase
                                                        Invoice</a>
                                                </li>
                                            @endif
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'purchase_return_voucher']) }}">Purchase
                                                        Return
                                                        Voucher</a></li>
                                            @endif
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'sales_invoice']) }}">Sales
                                                        Invoice</a></li>
                                            @endif
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'sale_return_voucher']) }}">Sale
                                                        Return
                                                        Voucher</a>
                                                </li>
                                            @endif
                                            @if (
                                                !empty(($branchId = session()->get('selected_branch'))) &&
                                                    Branches::hasBranchPermission($branchId, 'terms-and-conditions'))
                                                <li><a
                                                        href="{{ route('crusher.terms_and_conditions.create', ['type' => 'quotation']) }}">Quotation</a>
                                                </li>
                                            @endif
                                        </ul>
                                    </li>
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'warehouse-master'))
                                        <li><a href="{{ route('crusher.warehouses.index') }}">Warehouse Master</a>
                                        </li>
                                    @endif
                                </ul>
                            </li>



                            <li>
                                <a href="javascript: void(0);" class="has-arrow waves-effect"
                                    onclick="toggleSubMenu(this)">
                                    <i class="mdi mdi-inbox-full"></i>
                                    <span>Transactions</span>
                                </a>
                                <ul class="sub-menu" aria-expanded="false" style="display: none;">
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-credit-note-sales-return-voucher'))
                                        <li><a href="{{ route('crusher.credit_notes.index') }}">Credit Note (Sales
                                                Return Voucher)</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-debit-note-purchase-return-voucher'))
                                        <li><a href="{{ route('crusher.debit_notes.index') }}">Debit Note
                                                (Purchase
                                                Return Voucher)</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-approval-voucher-delivery-notes'))
                                        <li><a href="{{ route('crusher.delivery_notes.index') }}">Delivery Notes</a>
                                        </li>
                                    @endif
                                    {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, ''))
                                        <li><a href="crusher-gate-pass-voucher.html">Gate Pass Voucher</a></li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-journal-voucher'))
                                        <li><a href="{{ route('crusher.journal_vouchers.index') }}">Journal
                                                Voucher</a></li>
                                    @endif

                                    {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, ''))
                                        <li><a href="crusher-mtn.html">Material Transfer Note Voucher</a></li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'opening-balances-for-inventory'))
                                        <li><a href="{{ route('crusher.opening_balances.index') }}">Opening Balances
                                                for
                                                Inventory</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-payment-voucher'))
                                        <li><a href="{{ route('crusher.payment_vouchers.index') }}">Payment
                                                Voucher</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'purchase-order'))
                                        <li><a href="{{ route('crusher.purchase_orders.index') }}">Purchase Order</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'purchase-invoice'))
                                        <li><a href="{{ route('crusher.purchase_invoices.index') }}">Purchase
                                                Invoice</a></li>
                                    @endif
                                    @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'quotation'))
                                        <li><a href="{{ route('crusher.quotations.index') }}">Quotation</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'view-print-receipt-voucher'))
                                        <li><a href="{{ route('crusher.receipt_vouchers.index') }}">Receipt
                                                Voucher</a></li>
                                    @endif
                                    {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'payment-vouchers'))
                                        <li><a href="{{ route('show.payments.vouchers') }}">Payment
                                                Voucher</a></li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'sales-invoice'))
                                        <li><a href="{{ route('crusher.admin_sales_invoice.index') }}">Sales
                                                Invoice</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'warehouse-transfer'))
                                        <li><a href="{{ route('crusher.warehouse_transfers.index') }}">Warehouse
                                                Transfer</a></li>
                                    @endif
                                </ul>
                            </li>

                            <li>
                                <a href="javascript: void(0);" class="has-arrow waves-effect"
                                    onclick="toggleSubMenu(this)">
                                    <i class="mdi mdi-calendar-check"></i>
                                    <span>Reports</span>
                                </a>
                                <ul class="sub-menu" aria-expanded="false" style="display: none;">
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'cash-report'))
                                        <li><a href="{{ url('/statement-of-accounts/cash/ledger') }}">Cash Report</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'balance-sheet-report'))
                                        <li><a href="{{ url('/balance_sheet/view') }}">Balance Sheet</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'approval-voucher-and-do-report'))
                                        <li><a href="{{ url('/approval_do_report/view') }}"> Delivery Report</a>
                                        </li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'day-book-report'))
                                        <li><a href="{{ url('/day_book/view') }}">Day Book Report</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'discount-report'))
                                        <li><a href="{{ url('/statement-of-accounts/discount/ledger') }}">Discount Report</a></li>
                                    @endif
                                    {{-- @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'group-summay-report'))
                                        <li><a href="{{ url('/group_summary/view') }}">Group Summary</a></li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'purchase-report'))
                                        <li><a href="{{ url('/purchase_report/view') }}">Purchase Report</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'profit-and-loss-report'))
                                        <li><a href="{{ url('/profit_loss/view') }}">Profit & Loss Report</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'statement-of-account-report'))
                                        <li><a href="{{ url('/statement-of-accounts/view') }}">Statement of
                                                Accounts</a>
                                    @endif
                                    @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'stock-report'))
                                        <li><a href="{{ url('/stock_report/view') }}">Stock Report</a></li>
                                    @endif
                                    @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'sales-report'))
                                        <li><a href="{{ url('/sales_report/view') }}">Sales Report</a></li>
                                    @endif
                                    {{-- @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'salesmen-report'))
                                        <li><a href="{{ url('/salesman_report/view') }}">Salesman Report</a></li>
                                    @endif --}}
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'trial-balance-report'))
                                        <li><a href="{{ url('/trail_balance/view') }}">Trial Balance Report</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'official-vat-report'))
                                        <li><a href="{{ url('/statement-of-accounts/vat/ledger') }}">Vat Report</a></li>
                                    @endif
                                </ul>
                            </li>


                            <li>
                                @if (
                                    !empty(($branchId = session()->get('selected_branch'))) &&
                                        Branches::hasBranchPermission($branchId, 'other-account-master'))
                                    <a href="javascript: void(0);" class="has-arrow waves-effect"
                                        onclick="toggleSubMenu(this)">
                                        <i class="mdi mdi-account-circle-outline"></i>
                                        <span>Others</span>
                                    </a>
                                @endif

                                <ul class="sub-menu" aria-expanded="false" style="display: none;">
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'document-expiry'))
                                        <li><a href="crusher-document-expiry.html">Document Expiry</a></li>
                                    @endif
                                    @if (
                                        !empty(($branchId = session()->get('selected_branch'))) &&
                                            Branches::hasBranchPermission($branchId, 'notifications'))
                                        <li><a href="{{ route('crusher.notifications.index') }}">Notifications</a>
                                        </li>
                                    @endif
                                </ul>
                            </li>


                            @if (
                                !empty(($branchId = session()->get('selected_branch'))) &&
                                    Branches::hasBranchPermission($branchId, 'stock-search-permissions'))
                                <li>
                                    <a href="{{ route('StockSearch') }}" class=" waves-effect">
                                        <i class="dripicons-search"></i>
                                        <span>Stock Search</span>
                                    </a>
                                </li>
                            @endif

                            {{-- @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'customers-account-master')) --}}
                            <li>
                                <a href="{{ route('crusher.reminders.index') }}" class=" waves-effect">
                                    <i class="far fa-bell"></i>
                                    <span>Reminders</span>
                                </a>
                            </li>
                            {{-- @endif --}}
                            @if (!empty(($branchId = session()->get('selected_branch'))) && Branches::hasBranchPermission($branchId, 'chat'))
                                <li>
                                    <a href="crusher-chat.html" class=" waves-effect">
                                        <i class="dripicons-message"></i>
                                        <span>Chat</span>
                                    </a>
                                </li>
                            @endif




                        </ul>
                    </div>
                    <!-- Sidebar -->
                    <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>

                    {{-- <script>
                        $(document).ready(function () {
                            // Function to close all submenus
                            function closeAllSubMenus() {
                                $('.sub-menu').stop().slideUp().removeClass('active');
                            }

                            // Function to toggle submenu
                            function toggleSubMenu(element, e) {
                                // Prevent the default anchor link behavior
                                e.preventDefault();

                                // If the clicked submenu is already open, close it
                                if ($(element).siblings('.sub-menu').hasClass('active')) {
                                    closeAllSubMenus();
                                } else {
                                    // Close all submenus
                                    closeAllSubMenus();

                                    // Toggle 'active' class for the clicked submenu
                                    $(element).siblings('.sub-menu').stop().slideDown().toggleClass('active');
                                }
                            }

                            // Event listener for submenu toggle
                            $('.has-arrow').on('click', function (e) {
                                toggleSubMenu(this, e);
                            });
                        });
                    </script> --}}



                </div>
            </div>
            <!-- Left Sidebar End -->

            <!-- ============================================================== -->
            <!-- Start right Content here -->
            <!-- ============================================================== -->
            @php
                // use App\Branches;
                use Illuminate\Http\Request;
                use App\ReceivedVoucher;
                use App\MarketingDashboardImage;
                use Illuminate\Support\Facades\Session;

                $dashboardImage = MarketingDashboardImage::find(1);
                // $branches = Branches::with('company', 'permissions.permission')
                //     ->whereHas('company', function ($q) {
                //         $q->where('user_id', session()->get('uv_user_id'));
                //     })
                //     ->get();
                // Get the ID of the currently selected branch from the session
                $selectedBranchId = session('selected_branch');

                // Find the selected branch within the fetched branches
                // $selectedBranch = $branches->first(function ($branch) use ($selectedBranchId) {
                //     return $branch->id == $selectedBranchId;
                // });
                $selectedBranch = Branches::with('company')->find($selectedBranchId);
            @endphp
            <div class="main-content">

                <div class="page-content">
                    <!-- start page title -->
                    <div class="row">
                        <div class="col-12">
                            <div class="page-title-box d-flex align-items-center justify-content-between">
                                <div class="font-size-16 col-md-8" id="dashboardText">
                                    @if (!session('selected_branch'))
                                        <h4 class="page-title mb-0 font-size-18">Dashboard</h4>
                                    @else
                                        <h4 class="text-white">{{ $selectedBranch->company->name }} |
                                            {{ $selectedBranch->name }}</h4>
                                    @endif
                                </div>


                                <div class="page-title-right">
                                    <ol class="breadcrumb m-0">
                                        <h4 class="page-title mb-0 font-size-18">Powered By ACP</h4>
                                    </ol>
                                </div>

                            </div>
                        </div>
                    </div>
                    <!-- end page title -->
                    <!-- start page title -->
                    {{-- <div class="row">
                    <div class="col-12">
                        <div class="page-title-box d-flex align-items-center justify-content-between">
                            <div class="font-size-16 col-md-8" id="dashboardText">
                                @if (!session('selected_branch'))
                                    <h4>Dashboard</h4>
                                @else
                                    <h4>{{ $selectedBranch->company->name }} | {{ $selectedBranch->name }}</h4>
                                @endif
                            </div>


                            <div class="page-title-right">
                                <ol class="breadcrumb m-0">
                                </ol>
                            </div>

                        </div>
                    </div>
                </div> --}}
                    <!-- end page title -->
                    @yield('content')
                    <!-- End Page-content -->

                    <footer class="footer">
                        <div class="container-fluid">
                            <div class="row">
                                <div class="col-sm-6">
                                    <script>
                                        document.write(new Date().getFullYear())
                                    </script> © ACP
                                </div>
                                <div class="col-sm-6">
                                    <div class="text-sm-right d-none d-sm-block">
                                        Powerd By ACP
                                    </div>
                                </div>
                            </div>
                        </div>
                    </footer>
                </div>
                <!-- end main content-->

            </div>
            <!-- END layout-wrapper -->

        </div>
        <!-- end container-fluid -->

        <!-- JAVASCRIPT -->
        @yield('scripts')
        <script src="https://code.jquery.com/jquery-3.7.0.js" integrity="sha256-JlqSTELeR4TLqP0OG9dxM7yDPqX1ox/HfgiSLBj8+kM="
            crossorigin="anonymous"></script>
        <script src="{{ asset('assets/libs/jquery/jquery.min.js') }}"></script>
        <script src="{{ asset('assets/libs/bootstrap/js/bootstrap.bundle.min.js') }}"></script>
        {{-- <script src="{{asset('assets/libs/metismenu/metisMenu.min.js')}}"></script> --}}
        <script src="{{ asset('assets/libs/simplebar/simplebar.min.js') }}"></script>
        <script src="{{ asset('assets/libs/node-waves/waves.min.js') }}"></script>

        <!-- apexcharts -->
        <script src="{{ asset('assets/libs/apexcharts/apexcharts.min.js') }}"></script>
        <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
        <script src="{{ asset('assets/js/pages/form-advanced.init.js') }}"></script>

        <!-- jquery.vectormap map -->
        <script src="{{ asset('assets/libs/admin-resources/jquery.vectormap/jquery-jvectormap-1.2.2.min.js') }}"></script>
        <script src="{{ asset('assets/libs/admin-resources/jquery.vectormap/maps/jquery-jvectormap-us-merc-en.js') }}">
        </script>

        <script src="{{ asset('assets/js/pages/dashboard.init.js') }}"></script>

        <script src="{{ asset('assets/js/common.js') }}"></script>
        <script src="{{ asset('assets/js/app.js') }}"></script>

        <!-- form repeater js -->
        <script src="assets/libs/jquery.repeater/jquery.repeater.min.js"></script>

        <!-- form repeater init -->
        <script src="assets/js/pages/form-repeater.init.js"></script>

        <script src="assets/js/app.js"></script>

        <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.js"></script>

        {{-- <script src="{{ asset('assets/js/jquery-3.3.1.min.js') }}"></script> --}}
        <script src="{{ asset('assets/js/jquery.multiselect.js') }}"></script>
        <script src="{{ asset('assets/js/main.js') }}"></script>

        <script>
            $(document).ready(function() {
                // Select only tables with id="datatable"
                $("table#datatable").each(function() {
                    // Calculate the number of columns in the current table
                    var numColumns = $(this).find("thead th").length;

                    // Initialize DataTable with descending order on all columns
                    $(this).DataTable({
                        "order": Array(numColumns).fill([0,
                            "desc"
                        ]) // Create an array for descending order on all columns
                    });
                });
            });


            function toggleSubMenu(link) {
                var subMenu = link.nextElementSibling;
                subMenu.style.display = subMenu.style.display === "none" ? "block" : "none";
            }

            document.addEventListener("DOMContentLoaded", function() {
                var currentUrl = window.location.href;
                var branchQueryParam = getQueryParamValue("branch");
                var expire = {{ $expire ? 'true' : 'false' }};
                var BranchBlock = {{ !$status ? 'true' : 'false' }};

                // Check if either "expire" or "leniencyExpire" condition is met
                if (expire || BranchBlock) {
                    var sidebarLinks = document.querySelectorAll("#side-menu a");
                    sidebarLinks.forEach(function(link) {
                        if (!link.classList.contains("disabled-link")) {
                            link.setAttribute("disabled", true);
                            link.style.pointerEvents = "none";
                            link.style.color = "#ccc";
                        }
                    });
                }
            });

            function getQueryParamValue(paramName) {
                var urlParams = new URLSearchParams(window.location.search);
                return urlParams.get(paramName);
            }

            function numberToWords(number) {
                if (number === 0) return "zero";

                // Split the number into integer and fractional parts
                var integerPart = Math.floor(number);
                var fractionalPart = number - integerPart;

                // Convert the integer part to words
                var integerWords = convertToWords(integerPart);

                // Convert the fractional part to words
                var fractionalWords = convertToWords(Math.round(fractionalPart * 100)); // Convert fractional part to cents

                var result = "{{ $branch->currency_detail }} " + integerWords;

                if (fractionalWords !== "") {
                    result += " " + "and" + " " + fractionalWords + " " + "{{ $branch->minal_unit }}" + " " +
                        "only"; // Use Laravel variable correctly
                }

                return result.trim();
            }

            function convertToWords(number) {
                var ones = [
                    "", "one", "two", "three", "four", "five", "six", "seven", "eight", "nine",
                    "ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen", "sixteen", "seventeen",
                    "eighteen", "nineteen"
                ];

                var tens = [
                    "", "", "twenty", "thirty", "forty", "fifty", "sixty", "seventy", "eighty", "ninety"
                ];

                var scaleNames = ["", "thousand", "million", "billion", "trillion"];

                var scale = 0;
                var result = '';

                while (number > 0) {
                    if (number % 1000 !== 0) {
                        var currentChunk = number % 1000;
                        var chunkWords = '';

                        if (currentChunk >= 100) {
                            chunkWords += ones[Math.floor(currentChunk / 100)] + " hundred ";
                            currentChunk %= 100;
                        }

                        if (currentChunk >= 20) {
                            chunkWords += tens[Math.floor(currentChunk / 10)];
                            if (currentChunk % 10 !== 0) {
                                chunkWords += " ";
                                chunkWords += ones[currentChunk % 10];
                            }
                        } else if (currentChunk > 0) {
                            chunkWords += ones[currentChunk];
                        }

                        if (scale > 0) {
                            chunkWords += " " + scaleNames[scale];
                        }

                        result = chunkWords + " " + result;
                    }

                    number = Math.floor(number / 1000);
                    scale++;
                }

                return result.trim();

            }
        </script>

        <script>
            // NOTFICATION VIEW UPDATE
            function updateNotificationsViewed() {
                // Make an AJAX request to the notifications.updateViewed API
                // You can use libraries like jQuery or fetch API for this purpose
                // Example using fetch API:

                fetch("{{ route('crusher.notifications.updateViewed') }}", {
                        method: 'POST', // or 'GET' depending on your API
                        headers: {
                            'Content-Type': 'application/json',
                            // Add any additional headers required by your API
                        },
                        body: JSON.stringify({
                            // Add any data required by your API
                        })
                    })
                    .then(response => {
                        if (response.ok) {
                            // Update the UI to indicate that notifications are viewed
                            document.getElementById('unread-notification-count').textContent = '0';
                        } else {
                            // Handle error response from the API
                            console.error('Failed to update notifications');
                        }
                    })
                    .catch(error => {
                        console.error('Error:', error);
                    });
            }
        </script>
        <script>
            const body = document.body;
            const sidebarToggle = document.getElementById('sidebarToggle');

            sidebarToggle.addEventListener('click', function() {
                if (body.classList.contains('vertical-collpsed')) {
                    body.classList.remove('vertical-collpsed');
                    body.removeAttribute('data-keep-enlarged');
                    sidebarToggle.style.marginLeft = '13.5rem';
                } else {
                    body.classList.add('vertical-collpsed');
                    body.setAttribute('data-keep-enlarged', 'true');
                    sidebarToggle.style.marginLeft = '2.3rem';
                }
            });
        </script>
        <script>
            // Hide the loader when the entire page (including images and other resources) has loaded
            window.onload = function() {
                // Hide the loader
                $('.lds-dual-ring').fadeOut('slow', function() {
                    // You can add additional actions or show your content here
                    // For example, show the body content
                    $('body').css('visibility', 'visible');
                });
            };
        </script>
        <!-- Add this JavaScript code to your HTML -->
        {{-- <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script> --}}
        <!-- Add this JavaScript code to your HTML -->


        <script>
            $(document).ready(function() {
                // Retrieve the active link from local storage (if set)
                var activeLink = localStorage.getItem('activeLink');

                // Remove active class for all menu items
                $('#sidebar-menu ul li a.waves-effect').removeClass('active');

                // If an active link is stored, add the active class
                if (activeLink) {
                    $(activeLink).addClass('active');
                }

                // Sidebar menu item click event handler
                $('#sidebar-menu ul li a.waves-effect').click(function() {
                    // Remove active class for all menu items
                    $('#sidebar-menu ul li a.waves-effect').removeClass('active');

                    // Add active class for the clicked menu item
                    $(this).addClass('active');

                    // Store the active link in local storage
                    localStorage.setItem('activeLink', '#' + $(this).attr(
                        'id')); // Assuming each link has a unique ID
                });
            });
        </script>

        <script>
            // Get a reference to the button with the data-toggle attribute
            const fullscreenButton = document.querySelector('[data-toggle="fullscreen"]');

            // Add a click event listener to the button
            fullscreenButton.addEventListener('click', () => {
                toggleFullscreen();
            });

            // Function to toggle fullscreen mode
            function toggleFullscreen() {
                const element = document.documentElement; // Fullscreen the entire document
                if (!document.fullscreenElement && !document.mozFullScreenElement &&
                    !document.webkitFullscreenElement && !document.msFullscreenElement) {
                    // If not in fullscreen mode, request fullscreen
                    if (element.requestFullscreen) {
                        element.requestFullscreen();
                    } else if (element.msRequestFullscreen) {
                        element.msRequestFullscreen();
                    } else if (element.mozRequestFullScreen) {
                        element.mozRequestFullScreen();
                    } else if (element.webkitRequestFullscreen) {
                        element.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
                    }
                } else {
                    // If in fullscreen mode, exit fullscreen
                    if (document.exitFullscreen) {
                        document.exitFullscreen();
                    } else if (document.msExitFullscreen) {
                        document.msExitFullscreen();
                    } else if (document.mozCancelFullScreen) {
                        document.mozCancelFullScreen();
                    } else if (document.webkitExitFullscreen) {
                        document.webkitExitFullscreen();
                    }
                }
            }
        </script>
        <script>
            document.addEventListener('DOMContentLoaded', function () {
                var today = new Date().toISOString().split('T')[0];
                document.getElementById('from_date').value = today;
                document.getElementById('to_date').value = today;
            });
        </script>
        <script>
            document.addEventListener('DOMContentLoaded', function () {
                var today = new Date().toISOString().split('T')[0];
                document.getElementById('fromDate').value = today;
                document.getElementById('toDate').value = today;
            });
        </script>
</body>

</html>
